(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17325,        539]*)
(*NotebookOutlinePosition[     18008,        562]*)
(*  CellTagsIndexPosition[     17964,        558]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Pendulum", "Title"],

Cell["\<\
Renan Cabrera
rencabla@ceibo.entelnet.bo
2003\
\>", "Subtitle"],

Cell["\<\
Even thought the solution of the pendulum, which is a nonlinear mechanical \
system, can be written in terms of elliptic functions, the final evaluation \
is numerical. Perturbation methods are the practical analytical alternatives \
that give more insight into the problem. The pendulum is one of the simplest \
nonlinear systems, but the application of perturbation methods is still very \
extensive in the analytical calculations as we will see. In particular we are \
going to apply the Lie Perturbation technique to calculate the transformed \
Hamiltonian up to a second order.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<TMecanica1`TMecanica`\>"]\)}], "Input"],

Cell["In first place let's calculate the MASTER equation.", "Text"],

Cell[TextData[{
  "K(\[Eta]) = ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          StyleBox["T",
            FontSize->16,
            FontSlant->"Italic"], \(\(\ \)\(-1\)\)],
        FontSize->16]]],
  "H(",
  "\[Eta]",
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(\(MASTER = \((HamiltonianPerturbationExpansion[K, \[Epsilon], 2] == 
            Collect[Expand[
                InverseTOperatorPerturbationExpansion[G, 
                    Tensor[W], \[Epsilon], 2] /. 
                  Tensor[W] \[Rule] 
                    HamiltonianPerturbationExpansion[H, \[Epsilon], 
                      2]]\[IndentingNewLine], \[Epsilon]])\);\)\)], "Input"],

Cell["where we are sure of the expansion up to the 2nd order.", "Text"],

Cell["Now we continue the initialization of the base indices.", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{x, p}]\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input"],

Cell["\<\
Let's use \[Xi] as the label of the coordinates.\
\>", "Text"],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{\[Xi], G, H, K}, 1}, {{\[Delta], J}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {\[Xi], \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(\(\(SetTensorValues[\[Delta]ud[i, j] // ToFlavor[#], 
            IdentityMatrix[NDim]] &\) /@ {Identity, red};\)\)}], "Input"],

Cell["The Symplectic matrix for this dimension is:", "Text"],

Cell[BoxData[{
    \(SetSymplecticJValues[J, NDim]\), "\[IndentingNewLine]", 
    \(SetSymplecticJValues[J, NDim, red]\), "\[IndentingNewLine]", 
    \(Juu[\[Mu], \[Nu]] // ToArrayValues\), "\[IndentingNewLine]", 
    \(\(\(PartialD[_]\)[Tensor[J, __], _] = 0;\)\), "\[IndentingNewLine]", 
    \(\(PoissonB[J, _] := 0;\)\), "\[IndentingNewLine]", 
    \(\(PoissonB[_, J] := 0;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbative series expansion of the original Hamiltonian.", "Section"],

Cell["\<\
In first place let's define the Hamiltonian for the Pendulum.\
\>", "Text"],

Cell[BoxData[{
    \(\(ClearTensorValues[Tensor[Hp]];\)\), "\n", 
    \(\(ClearTensorValues[\[Xi]u[i]];\)\), "\n", 
    \(SetTensorValueRules[
      Tensor[Hp], \[Xi]u[p]\^2/\((2  m)\) + 
        m*\(\[Omega]\^2\) \((1 - Cos[\[Xi]u[x]])\)]\), "\n", 
    \(\(Attributes[\[Omega]] = {Constant};\)\), "\n", 
    \(\(Attributes[m] = {Constant};\)\)}], "Input"],

Cell[BoxData[
    \(H == Tensor[Hp] /. TensorValueRules[Hp]\)], "Input"],

Cell[TextData[{
  "where the x component of the coordinates is the oscillation angle, ",
  Cell[BoxData[
      \(m\)]],
  " is really the inertia moment and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontSize->16], 
          RowBox[{
            StyleBox[\(\[Omega]\^2\),
              FontSize->16], 
            StyleBox["=",
              FontSize->16], 
            StyleBox[" ",
              FontSize->16], 
            RowBox[{
              StyleBox["mg",
                FontSize->16], 
              StyleBox["/",
                FontSize->16], \(I\_m\)}]}]}], TraditionalForm]]],
  ", where this ",
  Cell[BoxData[
      \(I\_m\)]],
  " is the inertia moment."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
The first step in order to find the perturbative series is to expand the \
Hamiltonian in a Taylor series around zero in the x component.\
\>", "Text"],

Cell[BoxData[
    \(Series[\ \ Tensor[Hp] /. TensorValueRules[Hp]\ \ , {\[Xi]u[x], 0, 8}] // 
      Normal\)], "Input"],

Cell["\<\
Now we make the following variable substitution to introduce the perturbative \
parameter \[Epsilon].\
\>", "Text"],

Cell[BoxData[
    \({\[Xi]u[x] \[Rule] \ Sqrt[\[Epsilon]] \[Xi]u[x], \[Xi]u[p] \[Rule] 
          Sqrt[\[Epsilon]]\ \[Xi]u[p]} // TableForm\)], "Input"],

Cell[TextData[{
  "After dividing by ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  ", expanding and collecting in terms of the perturbative parameter gives:"
}], "Text"],

Cell[BoxData[
    \(PendulumPerturbativeExpansion = 
      Collect[\[IndentingNewLine]Expand[\[IndentingNewLine]Normal[
                Series[\ \ Tensor[Hp] /. 
                    TensorValueRules[Hp]\ \ , {\[Xi]u[x], 0, 8}]] /. {\[Xi]u[
                    x] \[Rule] \ 
                  Sqrt[\[Epsilon]] \[Xi]u[x], \[Xi]u[p] \[Rule] 
                  Sqrt[\[Epsilon]]\ \[Xi]u[
                      p]}\[IndentingNewLine]]/\[Epsilon], {\[Epsilon]}]\)], \
"Input"],

Cell["\<\
Now we fill the values rules for the different orders of the original \
hamiltonian manually up to the second order. We are using the head Tensor \
with label H, but this is only done for convenience.\
\>", "Text"],

Cell[BoxData[
    \(\(TensorValueRules[
          H] = \ {Tensor[
              H, {Void}, {0}] \[Rule] \(ExtractSeriesTerm[\[Epsilon], 0]\)[
              PendulumPerturbativeExpansion], 
          Tensor[H, {Void}, {1}] \[Rule] \(ExtractSeriesTerm[\[Epsilon], 1]\)[
              PendulumPerturbativeExpansion], 
          Tensor[H, {Void}, {2}] \[Rule] \(ExtractSeriesTerm[\[Epsilon], 2]\)[
              PendulumPerturbativeExpansion]};\)\)], "Input"],

Cell["\<\
Where we see that the zero order is just the Harmonic Oscillator.\
\>", "Text"],

Cell[BoxData[
    \(TensorValueRules[H] // TableForm\)], "Input"],

Cell["\<\
Now we use the canonical transformation that will reduce the zero order \
Hamiltonian to depend only on the momentum (action variables).\
\>", "Text"],

Cell[BoxData[{
    \(\(SetTensorValueRules[\[Xi]u[
          i], \[IndentingNewLine]{Sqrt[2  \[Xi]u[red@p]/\((\[Omega]*m)\)] 
            Cos[\[Xi]u[red@x]], 
          Sqrt[2  m*\[Omega]*\[Xi]u[red@p]] 
            Sin[\[Xi]u[
                red@x]]}\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(Equal @@ # &\) /@ TensorValueRules[\[Xi]]\)}], "Input"],

Cell["\<\
With this canonical transformation the respective orders of the series \
expansion are:\
\>", "Text"],

Cell[BoxData[
    \(OriginalHamiltonianValueRules = 
      Map[\ Factor[TrigReduce[#]] &, 
        TensorValueRules[H] /. TensorValueRules[\[Xi]] // 
          Simplify, {2}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Evaluation of the expanded MASTER equation ", "Section"],

Cell["\<\
Reviewing the \"Lie Perturbation Technique\" section that calculated the \
MASTER equation will facilitate understanding the following development.\
\>", "Text"],

Cell["Zero order:", "Text"],

Cell[BoxData[
    \(MASTERZeroOrder = \((MASTER // ExtractSeriesTerm[\[Epsilon], 0])\) /. 
        OriginalHamiltonianValueRules\)], "Input"],

Cell[BoxData[
    \(NewHamiltonianZeroOrderSol = \(Solve[MASTERZeroOrder, Tensor[K, {Void}, \
{0}]]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)], \
"Input"],

Cell["First Order:", "Text"],

Cell[BoxData[
    \(MASTERFirstOrder = \((MASTER // ExtractSeriesTerm[\[Epsilon], 1])\) /. 
        OriginalHamiltonianValueRules\)], "Input"],

Cell[TextData[{
  "expression where we do not know ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["G", 
          InterpretationBox["1",
            SequenceForm[ 1],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox["1",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 1, ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "yet."
}], "Text"],

Cell["Second Order", "Text"],

Cell[BoxData[
    \(MASTERSecondOrder = \((MASTER // 
          ExtractSeriesTerm[\[Epsilon], 2])\)\)], "Input"],

Cell[TextData[{
  "We left the second order basically unevaluated because we need ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["G", 
          InterpretationBox["1",
            SequenceForm[ 1],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox["1",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 1, ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "that will be calculated from the first order term of the Master equation."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Solving for ",
  Cell[BoxData[
      \(G\_1\)]],
  " and ",
  Cell[BoxData[
      \(K\_1\)]]
}], "Subsection"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["K", 
          InterpretationBox["0",
            SequenceForm[ 0],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox["0",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 0, ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " is found directly but we need some work to solve the other terms that \
involve the solution of the generator. The idea is to split the perturbation \
of the Hamiltonian in two parts:\n\na) Nondependent of the cyclic \
coordinates.\nb) Dependent of the cyclic coordinates including every Poisson \
bracket.\n\nThe cyclic coordinates (x in our case) are in general arguments \
of periodic functions."
}], "Text"],

Cell["\<\
For our particular case we define the following function that splits a \
expression into cyclic and noncyclic parts.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(MySplitCyclic::usage = "\<MySplitCyclic[expr] creates a list with \
the cyclic and nocyclic parts respectively.\n We assume that the Poisson \
brackets are functions of the cyclic coordinates. This function was designed \
to be used only in this section because we assume facts valid only \
here.\>";\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(MySplitCyclic[exp_] := 
      Module[{nc}, \[IndentingNewLine]nc = 
          Expand[exp /. {Cos[_] -> 0, Sin[_] -> 0, 
                PoissonB[__] -> 0, \(PartialD[_]\)[_, \[Xi]u[red@x]] -> 
                  0}]; \[IndentingNewLine]cy\  = \ \ Expand[\ 
            MapThread[
              Plus, {List @@ 
                  exp, \(-List @@ nc\)}]\ ]; \[IndentingNewLine]{Equal @@ cy, 
          nc}\[IndentingNewLine]]\)}], "Input"],

Cell["Applying to the first order part of the MASTER equation.", "Text"],

Cell[BoxData[
    \(MySplitCyclic[MASTERFirstOrder]\)], "Input"],

Cell["\<\
from this we find the first order term of the new Hamiltonian.\
\>", "Text"],

Cell[BoxData[
    \(NewHamiltonianFirstOrderSol = \(Solve[\(MySplitCyclic[\ \
MASTERFirstOrder]\)\_\(\(\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\
\), Tensor[K, {Void}, {1}]]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\)], "Input"],

Cell[TextData[{
  "Now we have to solve ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["G", 
              InterpretationBox["1",
                SequenceForm[ 1],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox["1",
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 1, ShowContents -> False]],
                Editable->False]],
            Subsuperscript[ G, 
              SequenceForm[ 1], 
              SequenceForm[ 
                StyleForm[ 1, ShowContents -> False]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " but we have to expand the Poisson brackets first."
}], "Text"],

Cell[BoxData[{
    \(\(MySplitCyclic[MASTERFirstOrder]\)\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)\), "\[IndentingNewLine]", 
    \(step1 = % // 
        FullExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, J, 
          red]\)}], "Input"],

Cell[TextData[{
  "Shifting terms, dividing and dividing by ",
  Cell[BoxData[
      \(\[Omega]\)]],
  " we can integrate the differential to obtain a solution for ",
  Cell[BoxData[
      \(G\_1\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(-Part[step1, 2, {1, 2}]\)/\[Omega] // 
      Cancel\), "\[IndentingNewLine]", 
    \(GeneratorFirstOrderSol = 
      Gd[1] \[Rule] Integrate[%, \[Xi]u[red@x]] // Simplify\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Solving for ",
  Cell[BoxData[
      \(G\_2\)]],
  " and ",
  Cell[BoxData[
      \(K\_2\)]]
}], "Subsection"],

Cell["\<\
Now lets go to the second order. Expanding and evaluating everything we have:\
\
\>", "Text"],

Cell[BoxData[{
    \(MASTERSecondOrder\ \), "\[IndentingNewLine]", 
    \(\(FullExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, J, 
        red]\)[%]\), "\[IndentingNewLine]", 
    \(ExpandedMASTERSecondOrder = \((\(% /. OriginalHamiltonianValueRules\) /. 
            GeneratorFirstOrderSol)\) // Simplify\)}], "Input"],

Cell["Now splitting the cyclic and noncyclic terms:", "Text"],

Cell[BoxData[
    \(MySplitCyclic[ExpandedMASTERSecondOrder]\)], "Input"],

Cell[BoxData[
    \(NewHamiltonianSecondOrderSol = \
\[IndentingNewLine]\(Solve[\(MySplitCyclic[ExpandedMASTERSecondOrder]\)\_\(\(\
\[LeftDoubleBracket]\)\(2\)\(\[RightDoubleBracket]\)\), Kd[2]]\)\_\(\(\
\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\)], "Input"],

Cell[CellGroupData[{

Cell["Final New Hamiltonian", "Subsubsection"],

Cell["\<\
Adding the three terms we have finally the following new hamiltonian that \
depends only in the new momentum. \
\>", "Text"],

Cell[BoxData[
    \(\(\(\(HamiltonianPerturbationExpansion[K, \[Epsilon], 2] /. 
            NewHamiltonianSecondOrderSol\) /. NewHamiltonianFirstOrderSol\) /. 
        NewHamiltonianZeroOrderSol\) /. \[Epsilon] -> 1\)], "Input"],

Cell[TextData[{
  "Home Work: Find ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["G", 
          InterpretationBox["2",
            SequenceForm[ 2],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox["2",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 2, ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " and the transformation function between the old and new coordinates."
}], "EmphasisText"],

Cell["I will develop more mechanic applications by request", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 29, 0, 76, "Title"],
Cell[1759, 54, 73, 4, 103, "Subtitle"],
Cell[1835, 60, 653, 11, 114, "Text"],

Cell[CellGroupData[{
Cell[2513, 75, 33, 0, 61, "Section"],
Cell[2549, 77, 142, 2, 66, "Input"],
Cell[2694, 81, 67, 0, 34, "Text"],
Cell[2764, 83, 305, 14, 34, "Text"],
Cell[3072, 99, 407, 7, 126, "Input"],
Cell[3482, 108, 71, 0, 34, "Text"],
Cell[3556, 110, 71, 0, 34, "Text"],
Cell[3630, 112, 125, 2, 66, "Input"],
Cell[3758, 116, 72, 2, 34, "Text"],
Cell[3833, 120, 349, 6, 86, "Input"],
Cell[4185, 128, 60, 0, 34, "Text"],
Cell[4248, 130, 392, 6, 146, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4677, 141, 77, 0, 61, "Section"],
Cell[4757, 143, 85, 2, 34, "Text"],
Cell[4845, 147, 356, 7, 126, "Input"],
Cell[5204, 156, 72, 1, 46, "Input"],
Cell[5279, 159, 775, 28, 54, "Text"],
Cell[6057, 189, 161, 3, 54, "Text"],
Cell[6221, 194, 119, 2, 46, "Input"],
Cell[6343, 198, 125, 3, 34, "Text"],
Cell[6471, 203, 152, 2, 46, "Input"],
Cell[6626, 207, 168, 5, 34, "Text"],
Cell[6797, 214, 469, 9, 126, "Input"],
Cell[7269, 225, 224, 4, 54, "Text"],
Cell[7496, 231, 455, 8, 106, "Input"],
Cell[7954, 241, 89, 2, 34, "Text"],
Cell[8046, 245, 65, 1, 46, "Input"],
Cell[8114, 248, 160, 3, 54, "Text"],
Cell[8277, 253, 366, 7, 106, "Input"],
Cell[8646, 262, 111, 3, 34, "Text"],
Cell[8760, 267, 187, 4, 86, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8984, 276, 62, 0, 61, "Section"],
Cell[9049, 278, 171, 3, 54, "Text"],
Cell[9223, 283, 27, 0, 34, "Text"],
Cell[9253, 285, 141, 2, 46, "Input"],
Cell[9397, 289, 176, 3, 47, "Input"],
Cell[9576, 294, 28, 0, 34, "Text"],
Cell[9607, 296, 142, 2, 46, "Input"],
Cell[9752, 300, 533, 17, 34, "Text"],
Cell[10288, 319, 28, 0, 34, "Text"],
Cell[10319, 321, 112, 2, 46, "Input"],
Cell[10434, 325, 633, 17, 54, "Text"],

Cell[CellGroupData[{
Cell[11092, 346, 129, 7, 49, "Subsection"],
Cell[11224, 355, 890, 21, 154, "Text"],
Cell[12117, 378, 140, 3, 34, "Text"],
Cell[12260, 383, 826, 15, 286, "Input"],
Cell[13089, 400, 72, 0, 34, "Text"],
Cell[13164, 402, 64, 1, 46, "Input"],
Cell[13231, 405, 86, 2, 34, "Text"],
Cell[13320, 409, 261, 4, 69, "Input"],
Cell[13584, 415, 872, 25, 34, "Text"],
Cell[14459, 442, 264, 5, 67, "Input"],
Cell[14726, 449, 218, 8, 34, "Text"],
Cell[14947, 459, 207, 4, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15191, 468, 129, 7, 49, "Subsection"],
Cell[15323, 477, 103, 3, 34, "Text"],
Cell[15429, 482, 326, 5, 106, "Input"],
Cell[15758, 489, 61, 0, 34, "Text"],
Cell[15822, 491, 73, 1, 46, "Input"],
Cell[15898, 494, 271, 4, 69, "Input"],

Cell[CellGroupData[{
Cell[16194, 502, 46, 0, 43, "Subsubsection"],
Cell[16243, 504, 134, 3, 34, "Text"],
Cell[16380, 509, 229, 3, 66, "Input"],
Cell[16612, 514, 590, 17, 48, "EmphasisText"],
Cell[17205, 533, 68, 0, 34, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

