(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     27522,        789]*)
(*NotebookOutlinePosition[     28205,        812]*)
(*  CellTagsIndexPosition[     28161,        808]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Canonical Transformations", "Title"],

Cell["\<\
Renan Cabrera
rencabla@ceibo.entelnet.bo
2003\
\>", "Subsubtitle"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<TMecanica1`TMecanica`\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell["Finite Canonical Transformations", "Section"],

Cell[TextData[{
  "A canonical transformation must obey certain constraints. This is because \
the form of the  equations must be conserved. Since the Poisson brackets of \
the coordinates are equal to the Symplectic matrix ",
  Cell[BoxData[
      \(J\)]],
  ", this must also be true for the new coordinate system. If it is true then \
the transformation is canonical."
}], "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{x, p}]\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input"],

Cell["\<\
From this point let's use \[Xi] as the label of the coordinates to avoid \
confusion.\
\>", "Text"],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{\[Xi]}, 1}, {{\[Delta], W, J}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {\[Xi], \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(\(\(SetTensorValues[\[Delta]ud[i, j] // ToFlavor[#], 
            IdentityMatrix[NDim]] &\) /@ {Identity, red};\)\)}], "Input"],

Cell["The Symplectic matrix in this system is:", "Text"],

Cell[BoxData[{
    \(SetSymplecticJValues[J, NDim]\), "\[IndentingNewLine]", 
    \(SetSymplecticJValues[J, NDim, red]\), "\[IndentingNewLine]", 
    \(Juu[\[Mu], \[Nu]] // ToArrayValues\)}], "Input"],

Cell["\<\
If the alternative coordinates have a red flavor index then the Poisson \
brackets of them are:\
\>", "Text"],

Cell[BoxData[{
    \(PoissonB[\[Xi]u[red@j], \[Xi]u[red@i]]\), "\[IndentingNewLine]", 
    \(\(% // ExpandPoissonB[labs, J, {\[Mu], \[Nu]}]\) // 
      KroneckerAbsorb[\[Delta]]\)}], "Input"],

Cell[TextData[{
  "We propose the following transformation to the red coordinate system. The \
meaning of ",
  Cell[BoxData[
      \(m\)]],
  " and ",
  Cell[BoxData[
      \(\[Omega]\)]],
  " will become clear later. "
}], "Text"],

Cell[BoxData[{
    \(\(ClearTensorValues[\[Xi]u[i]];\)\), "\[IndentingNewLine]", 
    \(\(SetTensorValueRules[\[Xi]u[
          red@i], \[IndentingNewLine]{Sqrt[2  \[Xi]u[p]/\((\[Omega]*m)\)] 
            Cos[\[Xi]u[x]], 
          Sqrt[2  m*\[Omega]*\[Xi]u[p]] 
            Sin[\[Xi]u[x]]}\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(Attributes[\[Omega]] = {Constant};\)\), "\[IndentingNewLine]", 
    \(\(Attributes[m] = {Constant};\)\), "\[IndentingNewLine]", 
    \(\(Equal @@ # &\) /@ TensorValueRules[\[Xi]] // TableForm\ \)}], "Input"],

Cell[TextData[{
  "Calculating the Poisson brackets of the new coordinates we obtain the \
Symplectic matrix ",
  Cell[BoxData[
      \(J\)]],
  " again, therefore the transformation is canonical and valid as we see \
next."
}], "Text"],

Cell[BoxData[{
    \(PoissonB[\[Xi]u[red@j], \[Xi]u[red@i]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[labs, J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(\(\(% // ToArrayValues\) // Simplify\) // PowerExpand\)}], "Input"],

Cell["\<\
It is easy to show that the determinant of the Jacobian is equal to 1. This \
ensures that the volume of the phase space is conserved.\
\>", "Text"],

Cell[BoxData[{
    \(\(PartialD[{\[Xi], \[Delta], g, \[CapitalGamma]}]\)[\[Xi]u[
        red@i], \[Xi]u[j]]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\), "\[IndentingNewLine]", 
    \(Jacobian\  == Abs[Det[%]] // 
      Simplify[#, m > 0 \[And] \[Omega] > 0] &\)}], "Input"],

Cell["\<\
What is this transformation good for ? This transformation is useful to \
simplify the Hamiltonian of the Harmonic Oscillator as we see next. \
\>", "Text"],

Cell["Our harmonic oscillator (H.O.) in the red flavor system is:", "Text"],

Cell[BoxData[
    \(SetTensorValueRules[
      Tensor[H], \[Xi]u[red@p]\^2/\((2  m)\) + 
        m*\(\[Omega]\^2\) \[Xi]u[red@x]\^2/2]\)], "Input"],

Cell[BoxData[
    \(H == Tensor[H] /. TensorValueRules[H]\)], "Input"],

Cell["The Hamilton equations in this system are:", "Text"],

Cell[BoxData[{
    \(PoissonB[\[Xi]u[red@i], Tensor[H]]\), "\[IndentingNewLine]", 
    \(TotalD[\[Xi]u[red@i], 
          t] == \(ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
            J, {\[Mu], \[Nu]}, red]\)[%] // 
      KroneckerAbsorb[\[Delta]]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[H]\)}], "Input"],

Cell[TextData[{
  "Where ",
  Cell[BoxData[
      \(m\)]],
  " is the mass, ",
  Cell[BoxData[
      \(\[Omega]\)]],
  " is the angular frequency of the harmonic oscillator. (The frequency of \
the H.O. is independent of the initial conditions and only depends on the \
material of the system including its mass). We could try to solve these \
differential equations but let's try a canonical transformation instead."
}], "Text"],

Cell[TextData[{
  "Using the rules of transformation to bring the system to the plain flavor \
system. (Now we know what ",
  Cell[BoxData[
      \(m\)]],
  " and ",
  Cell[BoxData[
      \(\[Omega]\)]],
  " are.)"
}], "Text"],

Cell[BoxData[{
    \(H == Tensor[H] /. TensorValueRules[H]\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[\[Xi]]\), "\[IndentingNewLine]", 
    \(% // Simplify\)}], "Input"],

Cell[TextData[{
  "The Hamiltonian  is now only a function of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox["p",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ p, ShowContents -> False]],
            Editable->False], 
          InterpretationBox["p",
            SequenceForm[ p],
            Editable->False]], TraditionalForm]]],
  " (where p is the second base index, which is the momentum). When the \
Hamiltonian can be written in a number of variables equal to half of the \
total number of degrees of freedom, we say that these coordinates are action \
variables. The variables that remain in the Hamiltonian explicitly are called \
the ",
  StyleBox["action momenta",
    FontSlant->"Italic"],
  ". The variables that do not appear explicitly in the Hamiltonian are \
called ",
  StyleBox["angular or cyclic coordinates",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
This new Hamiltonian generates the following Hamilton equations:\
\>", "Text"],

Cell[BoxData[{
    \(PoissonB[\[Xi]u[i], Tensor[H]]\), "\[IndentingNewLine]", 
    \(TotalD[\[Xi]u[i], 
        t] == \(ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
          J, {\[Mu], \[Nu]}]\)[%]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(% /. Tensor[H] \[Rule] \[Omega]*\[Xi]u[p]\)}], "Input"],

Cell[TextData[{
  "The Hamilton equations in this new system are very simple to solve. Here \
we must notice that the new momentum ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox["p",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ p, ShowContents -> False]],
            Editable->False], 
          InterpretationBox["p",
            SequenceForm[ p],
            Editable->False]], TraditionalForm]]],
  " is an integral of motion. When we start from a conservative system (no \
friction or loss of energy) the first integral of motion is the Hamiltonian \
itself. The new momentum is not a new integral of motion because there is \
only a constant from the Hamiltonian ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{"H", "=", 
              RowBox[{"\[Omega]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["p",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ p, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["p",
                        SequenceForm[ p],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ p, ShowContents -> False]], 
                      SequenceForm[ p]],
                    Editable->False],
                  "TraditionalForm"]}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
An integral of motion is not exactly the same as a constant. It is better to \
preserve the term constant for parameters that do not depend on any \
coordinate including the time. An integral of motion is a function of the \
coordinates that remains constant in time.\
\>", "EmphasisText",
  FontSlant->"Italic"],

Cell["\<\
The question is whether or not all conservative systems, with 2n dimensions, \
have a canonical transformation (even if we are not able to calculate them), \
which leads to Hamilton equations with \"n\" integrals of motion. The answer \
is NO! but if this is possible we say that the system is completely \
integrable. \
\>", "Text"],

Cell["\<\
Note: A 2 dimensional (x,p) conservative system like the simple Harmonic \
Oscillator is always completely integrable. \
\>", "Text"],

Cell["\<\
A system: (x1,x2,p1,p2) may be completely integrable but if this is not the \
case the solutions are less constrained and the path to CHAOS is open.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Infinitesimal Canonical Transformations", "Section"],

Cell["\<\
A very important case of canonical tranformations is one that makes a \
transformation to a new system infinitesimally close to the starting point, \
were we care only up to the first order term of some parameter that defines \
the new system.\
\>", "Text"],

Cell["In first place let's remove any value from the coordinates.", "Text"],

Cell[BoxData[{
    \(\(ClearTensorValues[\[Xi]u[i]];\)\), "\[IndentingNewLine]", 
    \(\(ClearTensorValues[\[Xi]u[red@i]];\)\)}], "Input"],

Cell["Let's define the next rule:", "Text"],

Cell[BoxData[{
    \(F2 = 
      Tensor[F\_2] -> \[Xi]u[x]*\[Xi]u[red@p] + \[Epsilon]*
            G[\[Xi]u[x], \[Xi]u[red@p]]\), "\[IndentingNewLine]", 
    \(\(Attributes[\[Epsilon]] = {Constant};\)\)}], "Input"],

Cell["\<\
where G is an arbitrary function and \[Epsilon] is an infinitesimal \
parameter.\
\>", "Text"],

Cell["\<\
Now we are going to propose that the next system of equations will generate a \
canonical transformation.\
\>", "Text"],

Cell[BoxData[
    \(Proposal = \[IndentingNewLine]{\[Xi]u[
            p] == \(PartialD[{\[Xi], \[Delta], g, \[CapitalGamma]}]\)[
            Tensor[F\_2], \[Xi]u[x]], \[IndentingNewLine]\[Xi]u[
            red@x] == \(PartialD[{\[Xi], \[Delta], g, \[CapitalGamma]}]\)[
            Tensor[F\_2], \[Xi]u[red@p]]}\)], "Input"],

Cell["\<\
Here we are going to need  a little bit of mental gymnastic to understand the \
following parts.\
\>", "Text"],

Cell["\<\
Mathematically we have initially four symmetric variables and two equations \
that will constrain the variables to only two independent variables. This \
means that the remaining variables will have to depend on the others without \
any alternative. \
\>", "Text"],

Cell[TextData[{
  "We can really choose any combination of pairs we want  but for covenience \
let's choose ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox["x",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ x, ShowContents -> False]],
            Editable->False], 
          InterpretationBox["x",
            SequenceForm[ x],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Xi]", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["p",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ p], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["p",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ p]],
                Editable->False]],
            Subsuperscript[ \[Xi], 
              SequenceForm[ 
                StyleForm[ 
                  red[ p], ShowContents -> False]], 
              SequenceForm[ 
                red[ p]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " as the independent variables. This means that:"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox["x",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ x, ShowContents -> False]],
            Editable->False], 
          InterpretationBox["x",
            SequenceForm[ x],
            Editable->False]], TraditionalForm]]],
  "  and  ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Xi]", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["p",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ p], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["p",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ p]],
                Editable->False]],
            Subsuperscript[ \[Xi], 
              SequenceForm[ 
                StyleForm[ 
                  red[ p], ShowContents -> False]], 
              SequenceForm[ 
                red[ p]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " are independent of each other provided that both  ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Xi]", 
              InterpretationBox[
                TagBox[
                  StyleBox["p",
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ p, ShowContents -> False]],
                Editable->False], 
              InterpretationBox["p",
                SequenceForm[ p],
                Editable->False]],
            Subsuperscript[ \[Xi], 
              SequenceForm[ 
                StyleForm[ p, ShowContents -> False]], 
              SequenceForm[ p]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["x",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ x], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["x",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ x]],
            Editable->False]], TraditionalForm]]],
  "  are  implicit  functions  of  ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox["x",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ x, ShowContents -> False]],
            Editable->False], 
          InterpretationBox["x",
            SequenceForm[ x],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Xi]", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["p",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ p], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["p",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ p]],
                Editable->False]],
            Subsuperscript[ \[Xi], 
              SequenceForm[ 
                StyleForm[ 
                  red[ p], ShowContents -> False]], 
              SequenceForm[ 
                red[ p]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  ". "
}], "EmphasisText",
  FontSize->16],

Cell["Writing this into a rule we have:", "Text"],

Cell[BoxData[
    \(ConstrainRule\  = \ {\ \(PartialD[{\[Xi], \[Delta], 
                g, \[CapitalGamma]}]\)[\[Xi]u[x], \[Xi]u[red@p]] \[Rule] \ 
          0, \(PartialD[{\[Xi], \[Delta], g, \[CapitalGamma]}]\)[\[Xi]u[
              red@p], \[Xi]u[x]] \[Rule] \ 0}\)], "Input"],

Cell["Evaluating the proposal with the constrain rule we obtain:", "Text"],

Cell[BoxData[
    \(\(Proposal /. F2\) /. ConstrainRule\)], "Input"],

Cell["\<\
This transformation means that when \[Epsilon] is zero the transformation is \
just the identity transformation. An infinitesimal transformation would be \
such that  \[Epsilon] would take an infinitesimal value close to zero.\
\>", "Text"],

Cell["\<\
Now making a variable change to write the new coordinates in terms of the \
variation:\
\>", "Text"],

Cell[BoxData[
    \(VariableChange = \[IndentingNewLine]{\[Xi]u[red@x] \[Rule] 
          TotalD[\[Xi]u[x]] + \[Xi]u[x], \[Xi]u[red@p] \[Rule] 
          TotalD[\[Xi]u[p]] + \[Xi]u[p]}\)], "Input"],

Cell["\<\
Applying this variable change we get the following equations:\
\>", "Text"],

Cell[BoxData[{
    \(\(\(Proposal /. F2\) /. ConstrainRule\) /. VariableChange // 
      Simplify\), "\[IndentingNewLine]", 
    \(% /. \[Xi]u[p] + _ \[Rule] \[Xi]u[p]\), "\[IndentingNewLine]", 
    \(\(MapAt[\(# - \[Epsilon]\ \(\(Derivative[1, 0]\)[G]\)[\[Xi]u[x], \[Xi]u[
                        p]] &\) /@ # &, %, 1] // Reverse\) // 
      TableForm\)}], "Input"],

Cell["\<\
where we neglected the variation in the arguments of G because we are \
interested only in the first order terms of \[Epsilon] and G is already \
affected by \[Epsilon].\
\>", "Text"],

Cell["Or with easy algebra:", "Text"],

Cell[BoxData[
    StyleBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["\[Mu]",
                      SequenceForm[ \[Mu]],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False]], 
                    SequenceForm[ \[Mu]]],
                  Editable->False],
                "TraditionalForm"]}], "=", 
            RowBox[{"\[Epsilon]", " ", 
              FormBox[
                RowBox[{"{", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["\[Mu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["\[Mu]",
                            SequenceForm[ \[Mu]],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ \[Mu], ShowContents -> False]], 
                          SequenceForm[ \[Mu]]],
                        Editable->False],
                      "TraditionalForm"], ",", 
                    FormBox["G",
                      "TraditionalForm"]}], "}"}],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)],
      FontWeight->"Bold",
      FontSlant->"Italic"]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[{
    \(TotalD[\[Xi]u[\[Mu]]] == \[Epsilon]\ \ PoissonB[\[Xi]u[\[Mu]], 
          Tensor[G]]\), "\[IndentingNewLine]", 
    \(% // FullExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input"],

Cell["\<\
Surprise! we could write the transformation variation with the use of the \
Poisson bracket.\
\>", "Text"],

Cell["\<\
But we have not prove yet that the proposed transformation is canonical. \
Let's go for that now. From the Proposal we had:\
\>", "Text"],

Cell[BoxData[
    \(\(Proposal /. F2\) /. ConstrainRule\)], "Input"],

Cell["This allow us to write the following transformation rules:", "Text"],

Cell[BoxData[
    \(TransformationRules = {\ \[Xi]u[
            red@p] \[Rule] \[Xi]u[
              p] - \[Epsilon]*\(\(Derivative[1, 0]\)[G]\)[\[Xi]u[x], \[Xi]u[
                  p]]\ , \[Xi]u[
            red@x] \[Rule] \[Xi]u[
              x] + \[Epsilon]*\(\(Derivative[0, 1]\)[G]\)[\[Xi]u[x], \[Xi]u[
                  p]]\ }\)], "Input"],

Cell["Now let's test the transformation.", "Text"],

Cell[BoxData[{
    \(PoissonB[\[Xi]u[red@i], \[Xi]u[red@j]]\), "\[IndentingNewLine]", 
    \(\(% // ExpandPoissonB[labs, J, {\[Mu], \[Nu]}]\) // 
      ToArrayValues\), "\[IndentingNewLine]", 
    \(% /. TransformationRules // Expand\), "\[IndentingNewLine]", 
    \(% /. \ \[Epsilon]\^2 \[Rule] 0\)}], "Input"],

Cell[TextData[{
  "where we neglected the second and higher order terms in ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "."
}], "Text"],

Cell["\<\
Therefore the proposed transformation is canonical and hopefully now we \
understand the Poisson bracket as a generator of variations of canonical \
transformations.\
\>", "EmphasisText"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
WindowSize->{716, 500},
WindowMargins->{{4, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 42, 0, 76, "Title"],
Cell[1772, 54, 76, 4, 79, "Subsubtitle"],
Cell[1851, 60, 142, 2, 66, "Input"],

Cell[CellGroupData[{
Cell[2018, 66, 51, 0, 61, "Section"],
Cell[2072, 68, 383, 8, 74, "Text"],
Cell[2458, 78, 125, 2, 66, "Input"],
Cell[2586, 82, 109, 3, 34, "Text"],
Cell[2698, 87, 343, 6, 106, "Input"],
Cell[3044, 95, 56, 0, 34, "Text"],
Cell[3103, 97, 200, 3, 86, "Input"],
Cell[3306, 102, 119, 3, 34, "Text"],
Cell[3428, 107, 191, 3, 66, "Input"],
Cell[3622, 112, 231, 9, 54, "Text"],
Cell[3856, 123, 556, 9, 166, "Input"],
Cell[4415, 134, 236, 7, 54, "Text"],
Cell[4654, 143, 238, 3, 86, "Input"],
Cell[4895, 148, 158, 3, 54, "Text"],
Cell[5056, 153, 337, 6, 106, "Input"],
Cell[5396, 161, 166, 3, 54, "Text"],
Cell[5565, 166, 75, 0, 34, "Text"],
Cell[5643, 168, 147, 3, 46, "Input"],
Cell[5793, 173, 70, 1, 46, "Input"],
Cell[5866, 176, 58, 0, 34, "Text"],
Cell[5927, 178, 408, 7, 126, "Input"],
Cell[6338, 187, 429, 11, 74, "Text"],
Cell[6770, 200, 226, 9, 54, "Text"],
Cell[6999, 211, 181, 3, 86, "Input"],
Cell[7183, 216, 1069, 28, 115, "Text"],
Cell[8255, 246, 88, 2, 34, "Text"],
Cell[8346, 250, 436, 7, 126, "Input"],
Cell[8785, 259, 2068, 52, 96, "Text"],
Cell[10856, 313, 322, 6, 88, "EmphasisText"],
Cell[11181, 321, 343, 6, 74, "Text"],
Cell[11527, 329, 143, 3, 54, "Text"],
Cell[11673, 334, 172, 3, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11882, 342, 58, 0, 61, "Section"],
Cell[11943, 344, 267, 5, 74, "Text"],
Cell[12213, 351, 75, 0, 34, "Text"],
Cell[12291, 353, 139, 2, 66, "Input"],
Cell[12433, 357, 43, 0, 34, "Text"],
Cell[12479, 359, 214, 4, 66, "Input"],
Cell[12696, 365, 104, 3, 34, "Text"],
Cell[12803, 370, 129, 3, 34, "Text"],
Cell[12935, 375, 324, 5, 86, "Input"],
Cell[13262, 382, 120, 3, 34, "Text"],
Cell[13385, 387, 274, 5, 74, "Text"],
Cell[13662, 394, 2095, 59, 55, "Text"],
Cell[15760, 455, 5770, 167, 72, "EmphasisText"],
Cell[21533, 624, 49, 0, 34, "Text"],
Cell[21585, 626, 280, 4, 66, "Input"],
Cell[21868, 632, 74, 0, 34, "Text"],
Cell[21945, 634, 68, 1, 46, "Input"],
Cell[22016, 637, 250, 4, 54, "Text"],
Cell[22269, 643, 110, 3, 34, "Text"],
Cell[22382, 648, 197, 3, 66, "Input"],
Cell[22582, 653, 85, 2, 34, "Text"],
Cell[22670, 657, 366, 6, 106, "Input"],
Cell[23039, 665, 193, 4, 54, "Text"],
Cell[23235, 671, 37, 0, 34, "Text"],
Cell[23275, 673, 2463, 59, 35, "Text"],
Cell[25741, 734, 281, 5, 86, "Input"],
Cell[26025, 741, 116, 3, 34, "Text"],
Cell[26144, 746, 147, 3, 54, "Text"],
Cell[26294, 751, 68, 1, 46, "Input"],
Cell[26365, 754, 74, 0, 34, "Text"],
Cell[26442, 756, 347, 7, 86, "Input"],
Cell[26792, 765, 50, 0, 34, "Text"],
Cell[26845, 767, 311, 5, 106, "Input"],
Cell[27159, 774, 135, 5, 34, "Text"],
Cell[27297, 781, 197, 4, 68, "EmphasisText"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

