(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    174155,       4087]*)
(*NotebookOutlinePosition[    174838,       4110]*)
(*  CellTagsIndexPosition[    174794,       4106]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Generators", "Title"],

Cell["\<\
Renan Cabrera
rencabla@ceibo.entelnet.bo
2003\
\>", "Subsubtitle"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<TMecanica1`TMecanica`\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell["Angular Momentum as the Rotation Generator", "Subsection"],

Cell["\<\
As the Hamiltonian generates translations in time, given by the Hamilton \
equations, the angular momentum is the generator of rotations.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "In this section we use ",
  Cell[BoxData[
      \(x\)]],
  ", ",
  Cell[BoxData[
      \(y\)]],
  " and ",
  Cell[BoxData[
      \(z\)]],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["for the regular space, also called configuration space. ",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      \(Px\)]],
  ", ",
  Cell[BoxData[
      \(Py\)]],
  " and ",
  Cell[BoxData[
      \(Pz\)]],
  " are the respective momenta."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(DeclareBaseIndices[{x, y, z, Px, Py, Pz}]\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input"],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{\[Xi], L, P}, 1}, {{\[Delta], J}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {\[Xi], \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(\(\(SetTensorValues[\[Delta]ud[i, j] // ToFlavor[#], 
            IdentityMatrix[NDim]] &\) /@ {Identity, red};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetSymplecticJValues[J, NDim]\), "\[IndentingNewLine]", 
    \(SetSymplecticJValues[J, NDim, red]\), "\[IndentingNewLine]", 
    \(Juu[\[Mu], \[Nu]] // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "0", "1", "0", "0"},
                {"0", "0", "0", "0", "1", "0"},
                {"0", "0", "0", "0", "0", "1"},
                {\(-1\), "0", "0", "0", "0", "0"},
                {"0", \(-1\), "0", "0", "0", "0"},
                {"0", "0", \(-1\), "0", "0", "0"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["The three components of the Angular momentum are:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Lz = \[Xi]u[x] \[Xi]u[Py] - \[Xi]u[y] \[Xi]u[
            Px]\), "\[IndentingNewLine]", 
    \(Lx = \[Xi]u[y] \[Xi]u[Pz] - \[Xi]u[z] \[Xi]u[
            Py]\), "\[IndentingNewLine]", 
    \(Ly = \[Xi]u[z] \[Xi]u[Px] - \[Xi]u[x] \[Xi]u[Pz]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["Py",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ Py, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["Py",
                      SequenceForm[ Py],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ Py, ShowContents -> False]], 
                    SequenceForm[ Py]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["x",
                      SequenceForm[ x],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]], 
                    SequenceForm[ x]],
                  Editable->False],
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["Px",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ Px, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["Px",
                      SequenceForm[ Px],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ Px, ShowContents -> False]], 
                    SequenceForm[ Px]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["y",
                      SequenceForm[ y],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ y, ShowContents -> False]], 
                    SequenceForm[ y]],
                  Editable->False],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["Pz",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ Pz, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["Pz",
                      SequenceForm[ Pz],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ Pz, ShowContents -> False]], 
                    SequenceForm[ Pz]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["y",
                      SequenceForm[ y],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ y, ShowContents -> False]], 
                    SequenceForm[ y]],
                  Editable->False],
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["Py",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ Py, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["Py",
                      SequenceForm[ Py],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ Py, ShowContents -> False]], 
                    SequenceForm[ Py]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["z",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ z, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["z",
                      SequenceForm[ z],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ z, ShowContents -> False]], 
                    SequenceForm[ z]],
                  Editable->False],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["Px",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ Px, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["Px",
                      SequenceForm[ Px],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ Px, ShowContents -> False]], 
                    SequenceForm[ Px]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["z",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ z, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["z",
                      SequenceForm[ z],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ z, ShowContents -> False]], 
                    SequenceForm[ z]],
                  Editable->False],
                "TraditionalForm"]}], "-", 
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["Pz",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ Pz, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["Pz",
                      SequenceForm[ Pz],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ Pz, ShowContents -> False]], 
                    SequenceForm[ Pz]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["x",
                      SequenceForm[ x],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]], 
                    SequenceForm[ x]],
                  Editable->False],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now assign these values to a tensor with label ",
  StyleBox["L ",
    FontWeight->"Bold"],
  "that is going to represent the angular momentum."
}], "Text"],

Cell[BoxData[
    \(SetTensorValueRules[Lu[i], {Lx, Ly, Lz, 0, 0, 0}]\)], "Input"],

Cell[TextData[{
  "Now, given ",
  Cell[BoxData[
      \(\[Delta]\[Theta]\)]],
  " as the differential parameter of the transformation, we obtain the \
following variation of the coordinates ",
  Cell[BoxData[
      \(\[Xi]\^i\)]],
  " under the effect of the ",
  Cell[BoxData[
      \(z\)]],
  " component of the angular momentum:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Delta]\[Theta]*PoissonB[\[Xi]u[i], Lu[z]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"\[Delta]\[Theta]", " ", 
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["i",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ i, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["i",
                          SequenceForm[ i],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ i, ShowContents -> False]], 
                        SequenceForm[ i]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]], 
                        SequenceForm[ z]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"\[Delta]\[Theta]", " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["J", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                    SequenceForm[ \[Mu], \[Nu]],
                    Editable->False]],
                Subsuperscript[ J, 
                  SequenceForm[ 
                    StyleForm[ \[Mu], ShowContents -> False], 
                    StyleForm[ \[Nu], ShowContents -> False]], 
                  SequenceForm[ \[Mu], \[Nu]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Delta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "\[Mu]"}],
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False], \[Mu]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{"i", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ i, 
                      StyleForm[ \[Mu], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Delta], 
                  SequenceForm[ 
                    StyleForm[ i, ShowContents -> False], \[Mu]], 
                  SequenceForm[ i, 
                    StyleForm[ \[Mu], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              TagBox[
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["L", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["z",
                            SequenceForm[ z],
                            Editable->False]],
                        Subsuperscript[ L, 
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]], 
                          SequenceForm[ z]],
                        Editable->False],
                      "TraditionalForm"]}], 
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["\[Nu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["\[Nu]",
                            SequenceForm[ \[Nu]],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ \[Nu], ShowContents -> False]], 
                          SequenceForm[ \[Nu]]],
                        Editable->False],
                      "TraditionalForm"]}],
                  MultilineFunction->None],
                HoldForm],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"{", 
            RowBox[{
              RowBox[{\(-\[Delta]\[Theta]\), " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["y",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["y",
                        SequenceForm[ y],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]], 
                      SequenceForm[ y]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{"\[Delta]\[Theta]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["x",
                        SequenceForm[ x],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]], 
                      SequenceForm[ x]],
                    Editable->False],
                  "TraditionalForm"]}], ",", "0", ",", 
              RowBox[{\(-\[Delta]\[Theta]\), " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["Py",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ Py, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["Py",
                        SequenceForm[ Py],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ Py, ShowContents -> False]], 
                      SequenceForm[ Py]],
                    Editable->False],
                  "TraditionalForm"]}], ",", 
              RowBox[{"\[Delta]\[Theta]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["Px",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ Px, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["Px",
                        SequenceForm[ Px],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ Px, ShowContents -> False]], 
                      SequenceForm[ Px]],
                    Editable->False],
                  "TraditionalForm"]}], ",", "0"}], "}"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "the variation that corresponds to a differential rotation around the ",
  Cell[BoxData[
      \(z\)]],
  " axis. We say that ",
  Cell[BoxData[
      \(Lz\)]],
  " is the generator of rotations along the z axis and something similar \
happens with ",
  Cell[BoxData[
      \(Ly\)]],
  " and ",
  Cell[BoxData[
      \(Lx\)]],
  ". The Poisson Brackets applied to ",
  Cell[BoxData[
      \(Lz\)]],
  " is some kind of generalization of the Hamilton equations where we have ",
  Cell[BoxData[
      \(Lz\)]],
  " instead of the Hamiltonian."
}], "Text"],

Cell["\<\
This method is able to generate a rotation variation of any function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Delta]\[Theta]*
      PoissonB[\ \ F[\[Xi]u[x], \[Xi]u[y], \[Xi]u[z]]\ \ , \ \ Lu[
          z]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues /. TensorValueRules[\[Delta]]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"\[Delta]\[Theta]", " ", 
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"F", "(", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"]}], ")"}], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]], 
                        SequenceForm[ z]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"\[Delta]\[Theta]", " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["J", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                    SequenceForm[ \[Mu], \[Nu]],
                    Editable->False]],
                Subsuperscript[ J, 
                  SequenceForm[ 
                    StyleForm[ \[Mu], ShowContents -> False], 
                    StyleForm[ \[Nu], ShowContents -> False]], 
                  SequenceForm[ \[Mu], \[Nu]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              TagBox[
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["L", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["z",
                            SequenceForm[ z],
                            Editable->False]],
                        Subsuperscript[ L, 
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]], 
                          SequenceForm[ z]],
                        Editable->False],
                      "TraditionalForm"]}], 
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["\[Nu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["\[Nu]",
                            SequenceForm[ \[Nu]],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ \[Nu], ShowContents -> False]], 
                          SequenceForm[ \[Nu]]],
                        Editable->False],
                      "TraditionalForm"]}],
                  MultilineFunction->None],
                HoldForm],
              "TraditionalForm"], " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Delta]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", "\[Mu]"}],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False], \[Mu]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{"z", "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["\[Mu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ z, 
                            StyleForm[ \[Mu], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Delta], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False], \[Mu]], 
                        SequenceForm[ z, 
                          StyleForm[ \[Mu], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  RowBox[{
                    SuperscriptBox["F", 
                      TagBox[\((0, 0, 1)\),
                        Derivative],
                      MultilineFunction->None], "(", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"]}], ")"}]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Delta]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", "\[Mu]"}],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False], \[Mu]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{"y", "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["\[Mu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ y, 
                            StyleForm[ \[Mu], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Delta], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False], \[Mu]], 
                        SequenceForm[ y, 
                          StyleForm[ \[Mu], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  RowBox[{
                    SuperscriptBox["F", 
                      TagBox[\((0, 1, 0)\),
                        Derivative],
                      MultilineFunction->None], "(", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"]}], ")"}]}], "+", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Delta]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", "\[Mu]"}],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False], \[Mu]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{"x", "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["\[Mu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ x, 
                            StyleForm[ \[Mu], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[Delta], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False], \[Mu]], 
                        SequenceForm[ x, 
                          StyleForm[ \[Mu], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], " ", 
                  RowBox[{
                    SuperscriptBox["F", 
                      TagBox[\((1, 0, 0)\),
                        Derivative],
                      MultilineFunction->None], "(", 
                    RowBox[{
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"], ",", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"]}], ")"}]}]}], ")"}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"\[Delta]\[Theta]", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["x",
                      SequenceForm[ x],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]], 
                    SequenceForm[ x]],
                  Editable->False],
                "TraditionalForm"], " ", 
              RowBox[{
                SuperscriptBox["F", 
                  TagBox[\((0, 1, 0)\),
                    Derivative],
                  MultilineFunction->None], "(", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["x",
                          SequenceForm[ x],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]], 
                        SequenceForm[ x]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]], 
                        SequenceForm[ z]],
                      Editable->False],
                    "TraditionalForm"]}], ")"}]}], "-", 
            RowBox[{"\[Delta]\[Theta]", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[Xi]", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["y",
                      SequenceForm[ y],
                      Editable->False]],
                  Subsuperscript[ \[Xi], 
                    SequenceForm[ 
                      StyleForm[ y, ShowContents -> False]], 
                    SequenceForm[ y]],
                  Editable->False],
                "TraditionalForm"], " ", 
              RowBox[{
                SuperscriptBox["F", 
                  TagBox[\((1, 0, 0)\),
                    Derivative],
                  MultilineFunction->None], "(", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["x",
                          SequenceForm[ x],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]], 
                        SequenceForm[ x]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]], 
                        SequenceForm[ z]],
                      Editable->False],
                    "TraditionalForm"]}], ")"}]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we can calculate some important identities. The Poisson bracket give \
us ",
  Cell[BoxData[
      \({Lx, Ly}\  = \ Lz\)]],
  " and similarly for the other combinations. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PoissonB[Lu[x], Lu[y]] \[Equal] Lu[z]\), "\[IndentingNewLine]", 
    \(MapAt[
      ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}], %, 1]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["x",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["x",
                          SequenceForm[ x],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]], 
                        SequenceForm[ x]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["L", 
                  InterpretationBox[
                    TagBox[
                      StyleBox["z",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ z, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox["z",
                    SequenceForm[ z],
                    Editable->False]],
                Subsuperscript[ L, 
                  SequenceForm[ 
                    StyleForm[ z, ShowContents -> False]], 
                  SequenceForm[ z]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["J", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\[Mu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["\[Nu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                      SequenceForm[ \[Mu], \[Nu]],
                      Editable->False]],
                  Subsuperscript[ J, 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]], 
                    SequenceForm[ \[Mu], \[Nu]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Mu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Mu]",
                              SequenceForm[ \[Mu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]], 
                            SequenceForm[ \[Mu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Nu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Nu]",
                              SequenceForm[ \[Nu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]], 
                            SequenceForm[ \[Nu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"]}], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["L", 
                  InterpretationBox[
                    TagBox[
                      StyleBox["z",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ z, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox["z",
                    SequenceForm[ z],
                    Editable->False]],
                Subsuperscript[ L, 
                  SequenceForm[ 
                    StyleForm[ z, ShowContents -> False]], 
                  SequenceForm[ z]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["True",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PoissonB[Lu[y], Lu[z]] \[Equal] Lu[x]\), "\[IndentingNewLine]", 
    \(MapAt[
      ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}], %, 1]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["z",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["z",
                          SequenceForm[ z],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ z, ShowContents -> False]], 
                        SequenceForm[ z]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["L", 
                  InterpretationBox[
                    TagBox[
                      StyleBox["x",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox["x",
                    SequenceForm[ x],
                    Editable->False]],
                Subsuperscript[ L, 
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False]], 
                  SequenceForm[ x]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["J", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\[Mu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["\[Nu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                      SequenceForm[ \[Mu], \[Nu]],
                      Editable->False]],
                  Subsuperscript[ J, 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]], 
                    SequenceForm[ \[Mu], \[Nu]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Mu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Mu]",
                              SequenceForm[ \[Mu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]], 
                            SequenceForm[ \[Mu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Nu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Nu]",
                              SequenceForm[ \[Nu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]], 
                            SequenceForm[ \[Nu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"]}], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["L", 
                  InterpretationBox[
                    TagBox[
                      StyleBox["x",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox["x",
                    SequenceForm[ x],
                    Editable->False]],
                Subsuperscript[ L, 
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False]], 
                  SequenceForm[ x]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["True",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(L2\)]],
  " be the square angular momentum. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L2\  = Lu[x]\^2 + Lu[y]\^2 + Lu[z]\^2\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              TagBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"],
                      "TraditionalForm"], ")"}], "2"],
                DisplayForm],
              "TraditionalForm"], "+", 
            FormBox[
              TagBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"],
                      "TraditionalForm"], ")"}], "2"],
                DisplayForm],
              "TraditionalForm"], "+", 
            FormBox[
              TagBox[
                SuperscriptBox[
                  RowBox[{"(", 
                    FormBox[
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"],
                      "TraditionalForm"], ")"}], "2"],
                DisplayForm],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PoissonB[L2, Lu[y]] // HoldForm\), "\[IndentingNewLine]", 
    \(% // ReleaseHold\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(\(% // ToArrayValues\) // Simplify\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          TagBox[
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    FormBox[
                      TagBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubsuperscriptBox["L", 
                                    InterpretationBox[
                                      TagBox[
                                        StyleBox["x",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)],
                                      SequenceForm[ 
                                        StyleForm[ x, ShowContents -> False]],
                                      
                                      Editable->False], 
                                    InterpretationBox["x",
                                      SequenceForm[ x],
                                      Editable->False]],
                                  Subsuperscript[ L, 
                                    SequenceForm[ 
                                      StyleForm[ x, ShowContents -> False]], 
                                    SequenceForm[ x]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"], ")"}], "2"],
                        DisplayForm],
                      "TraditionalForm"], "+", 
                    FormBox[
                      TagBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubsuperscriptBox["L", 
                                    InterpretationBox[
                                      TagBox[
                                        StyleBox["y",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)],
                                      SequenceForm[ 
                                        StyleForm[ y, ShowContents -> False]],
                                      
                                      Editable->False], 
                                    InterpretationBox["y",
                                      SequenceForm[ y],
                                      Editable->False]],
                                  Subsuperscript[ L, 
                                    SequenceForm[ 
                                      StyleForm[ y, ShowContents -> False]], 
                                    SequenceForm[ y]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"], ")"}], "2"],
                        DisplayForm],
                      "TraditionalForm"], "+", 
                    FormBox[
                      TagBox[
                        SuperscriptBox[
                          RowBox[{"(", 
                            FormBox[
                              FormBox[
                                InterpretationBox[
                                  SubsuperscriptBox["L", 
                                    InterpretationBox[
                                      TagBox[
                                        StyleBox["z",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)],
                                      SequenceForm[ 
                                        StyleForm[ z, ShowContents -> False]],
                                      
                                      Editable->False], 
                                    InterpretationBox["z",
                                      SequenceForm[ z],
                                      Editable->False]],
                                  Subsuperscript[ L, 
                                    SequenceForm[ 
                                      StyleForm[ z, ShowContents -> False]], 
                                    SequenceForm[ z]],
                                  Editable->False],
                                "TraditionalForm"],
                              "TraditionalForm"], ")"}], "2"],
                        DisplayForm],
                      "TraditionalForm"]}], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"],
            HoldForm],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["L", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["x",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ x, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["x",
                                    SequenceForm[ x],
                                    Editable->False]],
                                Subsuperscript[ L, 
                                  SequenceForm[ 
                                    StyleForm[ x, ShowContents -> False]], 
                                  SequenceForm[ x]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["L", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["y",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ y, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["y",
                                    SequenceForm[ y],
                                    Editable->False]],
                                Subsuperscript[ L, 
                                  SequenceForm[ 
                                    StyleForm[ y, ShowContents -> False]], 
                                  SequenceForm[ y]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["L", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["z",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ z, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["z",
                                    SequenceForm[ z],
                                    Editable->False]],
                                Subsuperscript[ L, 
                                  SequenceForm[ 
                                    StyleForm[ z, ShowContents -> False]], 
                                  SequenceForm[ z]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["L", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["y",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["y",
                          SequenceForm[ y],
                          Editable->False]],
                      Subsuperscript[ L, 
                        SequenceForm[ 
                          StyleForm[ y, ShowContents -> False]], 
                        SequenceForm[ y]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{"2", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["J", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\[Mu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["\[Nu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                      SequenceForm[ \[Mu], \[Nu]],
                      Editable->False]],
                  Subsuperscript[ J, 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]], 
                    SequenceForm[ \[Mu], \[Nu]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["L", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["x",
                      SequenceForm[ x],
                      Editable->False]],
                  Subsuperscript[ L, 
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False]], 
                    SequenceForm[ x]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["x",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ x, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["x",
                              SequenceForm[ x],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]], 
                            SequenceForm[ x]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Mu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Mu]",
                              SequenceForm[ \[Mu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]], 
                            SequenceForm[ \[Mu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Nu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Nu]",
                              SequenceForm[ \[Nu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]], 
                            SequenceForm[ \[Nu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"]}], "+", 
            RowBox[{"2", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["J", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\[Mu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["\[Nu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                      SequenceForm[ \[Mu], \[Nu]],
                      Editable->False]],
                  Subsuperscript[ J, 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]], 
                    SequenceForm[ \[Mu], \[Nu]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["L", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["y",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ y, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["y",
                      SequenceForm[ y],
                      Editable->False]],
                  Subsuperscript[ L, 
                    SequenceForm[ 
                      StyleForm[ y, ShowContents -> False]], 
                    SequenceForm[ y]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Mu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Mu]",
                              SequenceForm[ \[Mu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]], 
                            SequenceForm[ \[Mu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Nu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Nu]",
                              SequenceForm[ \[Nu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]], 
                            SequenceForm[ \[Nu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"]}], "+", 
            RowBox[{"2", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["J", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\[Mu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["\[Nu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                      SequenceForm[ \[Mu], \[Nu]],
                      Editable->False]],
                  Subsuperscript[ J, 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]], 
                    SequenceForm[ \[Mu], \[Nu]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["L", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["z",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ z, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["z",
                      SequenceForm[ z],
                      Editable->False]],
                  Subsuperscript[ L, 
                    SequenceForm[ 
                      StyleForm[ z, ShowContents -> False]], 
                    SequenceForm[ z]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["z",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["z",
                              SequenceForm[ z],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]], 
                            SequenceForm[ z]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Mu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Mu]",
                              SequenceForm[ \[Mu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]], 
                            SequenceForm[ \[Mu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["L", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["y",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["y",
                              SequenceForm[ y],
                              Editable->False]],
                          Subsuperscript[ L, 
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]], 
                            SequenceForm[ y]],
                          Editable->False],
                        "TraditionalForm"]}], 
                    RowBox[{"\[PartialD]", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[Xi]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["\[Nu]",
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)],
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]],
                              Editable->False], 
                            InterpretationBox["\[Nu]",
                              SequenceForm[ \[Nu]],
                              Editable->False]],
                          Subsuperscript[ \[Xi], 
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]], 
                            SequenceForm[ \[Nu]]],
                          Editable->False],
                        "TraditionalForm"]}],
                    MultilineFunction->None],
                  HoldForm],
                "TraditionalForm"]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["0",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Oh! is zero.
When two functions have zero Poisson Bracket we say that the two functions \
commute. The square of the angular momentum commutes with each component.\
\>", "Text"],

Cell["\<\
If we have two integrals of motion, the system will evolve invariantly on the \
two parameters corresponding to each integral of motion.  The fact that two \
integrals of motion commute means that they are invariant of each other and \
one does not change the other. This means that the integrals of motion are \
independent and can be used simultaneously to constrain the movement of the \
system. \
\>", "EmphasisText"],

Cell["\<\
If we have a system that conserves the angular momentum then we can chose one \
component and the square magnitude as independent integrals of motion to \
constrain the solutions.\
\>", "Text"],

Cell["\<\
The components of the angular momentum do not commute with each other. This \
means that if the system evolves in the parameter of a particular component, \
then the system also evolves in the parameter of the other components. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear Momentum as the Translation Generator", "Subsection"],

Cell[TextData[{
  "The momentum is the generator of differential translations. For example \
the x component of the momentum ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Xi]", 
          InterpretationBox[
            TagBox[
              StyleBox["Px",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ Px, ShowContents -> False]],
            Editable->False], 
          InterpretationBox["Px",
            SequenceForm[ Px],
            Editable->False]], TraditionalForm]]],
  " is the generator of variations along the x axis."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dx*\ PoissonB[\[Xi]u[i], \[Xi]u[Px]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"dx", " ", 
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["i",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ i, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["i",
                          SequenceForm[ i],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ i, ShowContents -> False]], 
                        SequenceForm[ i]],
                      Editable->False],
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["Px",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ Px, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["Px",
                          SequenceForm[ Px],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ Px, ShowContents -> False]], 
                        SequenceForm[ Px]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"dx", " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["J", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                    SequenceForm[ \[Mu], \[Nu]],
                    Editable->False]],
                Subsuperscript[ J, 
                  SequenceForm[ 
                    StyleForm[ \[Mu], ShowContents -> False], 
                    StyleForm[ \[Nu], ShowContents -> False]], 
                  SequenceForm[ \[Mu], \[Nu]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Delta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "\[Mu]"}],
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False], \[Mu]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{"i", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ i, 
                      StyleForm[ \[Mu], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Delta], 
                  SequenceForm[ 
                    StyleForm[ i, ShowContents -> False], \[Mu]], 
                  SequenceForm[ i, 
                    StyleForm[ \[Mu], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Delta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["Px",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "\[Nu]"}],
                    SequenceForm[ 
                      StyleForm[ Px, ShowContents -> False], \[Nu]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{"Px", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ Px, 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Delta], 
                  SequenceForm[ 
                    StyleForm[ Px, ShowContents -> False], \[Nu]], 
                  SequenceForm[ Px, 
                    StyleForm[ \[Nu], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\({dx, 0, 0, 0, 0, 0}\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
This works in general, so that the variation of a scalar Tensor F along the x \
axis is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dx*\ PoissonB[\ Tensor[F], \[Xi]u[Px]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"dx", " ", 
            FormBox[
              RowBox[{"{", 
                RowBox[{
                  FormBox["F",
                    "TraditionalForm"], ",", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[Xi]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["Px",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ Px, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["Px",
                          SequenceForm[ Px],
                          Editable->False]],
                      Subsuperscript[ \[Xi], 
                        SequenceForm[ 
                          StyleForm[ Px, ShowContents -> False]], 
                        SequenceForm[ Px]],
                      Editable->False],
                    "TraditionalForm"]}], "}"}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"dx", " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["J", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                    SequenceForm[ \[Mu], \[Nu]],
                    Editable->False]],
                Subsuperscript[ J, 
                  SequenceForm[ 
                    StyleForm[ \[Mu], ShowContents -> False], 
                    StyleForm[ \[Nu], ShowContents -> False]], 
                  SequenceForm[ \[Mu], \[Nu]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Delta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["Px",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "\[Nu]"}],
                    SequenceForm[ 
                      StyleForm[ Px, ShowContents -> False], \[Nu]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{"Px", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ Px, 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Delta], 
                  SequenceForm[ 
                    StyleForm[ Px, ShowContents -> False], \[Nu]], 
                  SequenceForm[ Px, 
                    StyleForm[ \[Nu], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              TagBox[
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    FormBox["F",
                      "TraditionalForm"]}], 
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["\[Mu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["\[Mu]",
                            SequenceForm[ \[Mu]],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ \[Mu], ShowContents -> False]], 
                          SequenceForm[ \[Mu]]],
                        Editable->False],
                      "TraditionalForm"]}],
                  MultilineFunction->None],
                HoldForm],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"dx", " ", 
            FormBox[
              TagBox[
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    FormBox["F",
                      "TraditionalForm"]}], 
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["x",
                            SequenceForm[ x],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]], 
                          SequenceForm[ x]],
                        Editable->False],
                      "TraditionalForm"]}],
                  MultilineFunction->None],
                HoldForm],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
What happens if we calculate the Poisson bracket of the position and the \
momentum?\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PoissonB[\ \[Xi]u[x], \[Xi]u[Px]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{"{", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["x",
                        SequenceForm[ x],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]], 
                      SequenceForm[ x]],
                    Editable->False],
                  "TraditionalForm"], ",", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[Xi]", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["Px",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ Px, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["Px",
                        SequenceForm[ Px],
                        Editable->False]],
                    Subsuperscript[ \[Xi], 
                      SequenceForm[ 
                        StyleForm[ Px, ShowContents -> False]], 
                      SequenceForm[ Px]],
                    Editable->False],
                  "TraditionalForm"]}], "}"}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["J", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                    SequenceForm[ \[Mu], \[Nu]],
                    Editable->False]],
                Subsuperscript[ J, 
                  SequenceForm[ 
                    StyleForm[ \[Mu], ShowContents -> False], 
                    StyleForm[ \[Nu], ShowContents -> False]], 
                  SequenceForm[ \[Mu], \[Nu]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Delta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["Px",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "\[Nu]"}],
                    SequenceForm[ 
                      StyleForm[ Px, ShowContents -> False], \[Nu]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{"Px", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ Px, 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Delta], 
                  SequenceForm[ 
                    StyleForm[ Px, ShowContents -> False], \[Nu]], 
                  SequenceForm[ Px, 
                    StyleForm[ \[Nu], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Delta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["x",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "\[Mu]"}],
                    SequenceForm[ 
                      StyleForm[ x, ShowContents -> False], \[Mu]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{"x", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ x, 
                      StyleForm[ \[Mu], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Delta], 
                  SequenceForm[ 
                    StyleForm[ x, ShowContents -> False], \[Mu]], 
                  SequenceForm[ x, 
                    StyleForm[ \[Mu], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["1",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Oh! is not zero, that means that they are not independent. We cannot use them \
simultaneously to constrain the trajectories. Do not you feel some similarity \
with quatum mechanics?\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example.The Central Force System", "Subsection"],

Cell["\<\
A system with the potential depending only on the distance to the origin of \
coordinates has the following Hamiltonian.\
\>", "Text"],

Cell[BoxData[
    \(SetTensorValueRules[
      Tensor[Hc], \((\[Xi]u[Px]\^2 + \[Xi]u[Py]\^2 + \[Xi]u[Pz]\^2)\)/\((2  
              m)\) + V[\((\[Xi]u[x]\^2 + \[Xi]u[y]\^2 + \[Xi]u[z]\^2)\)]]\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hc == Tensor[Hc] /. TensorValueRules[Hc]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"Hc", "==", 
            RowBox[{
              FractionBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[Xi]", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["Px",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ Px, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["Px",
                                    SequenceForm[ Px],
                                    Editable->False]],
                                Subsuperscript[ \[Xi], 
                                  SequenceForm[ 
                                    StyleForm[ Px, ShowContents -> False]], 
                                  SequenceForm[ Px]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], "+", 
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[Xi]", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["Py",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ Py, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["Py",
                                    SequenceForm[ Py],
                                    Editable->False]],
                                Subsuperscript[ \[Xi], 
                                  SequenceForm[ 
                                    StyleForm[ Py, ShowContents -> False]], 
                                  SequenceForm[ Py]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], "+", 
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[Xi]", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["Pz",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ Pz, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["Pz",
                                    SequenceForm[ Pz],
                                    Editable->False]],
                                Subsuperscript[ \[Xi], 
                                  SequenceForm[ 
                                    StyleForm[ Pz, ShowContents -> False]], 
                                  SequenceForm[ Pz]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"]}], \(2\ m\)], "+", 
              RowBox[{"V", "(", 
                RowBox[{
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[Xi]", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["x",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ x, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["x",
                                    SequenceForm[ x],
                                    Editable->False]],
                                Subsuperscript[ \[Xi], 
                                  SequenceForm[ 
                                    StyleForm[ x, ShowContents -> False]], 
                                  SequenceForm[ x]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], "+", 
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[Xi]", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["y",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ y, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["y",
                                    SequenceForm[ y],
                                    Editable->False]],
                                Subsuperscript[ \[Xi], 
                                  SequenceForm[ 
                                    StyleForm[ y, ShowContents -> False]], 
                                  SequenceForm[ y]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"], "+", 
                  FormBox[
                    TagBox[
                      SuperscriptBox[
                        RowBox[{"(", 
                          FormBox[
                            FormBox[
                              InterpretationBox[
                                SubsuperscriptBox["\[Xi]", 
                                  InterpretationBox[
                                    TagBox[
                                      StyleBox["z",
                                        ShowContents->False],
                                      (
                                      StyleForm[ #, ShowContents -> False]&)],
                                    
                                    SequenceForm[ 
                                      StyleForm[ z, ShowContents -> False]],
                                    Editable->False], 
                                  InterpretationBox["z",
                                    SequenceForm[ z],
                                    Editable->False]],
                                Subsuperscript[ \[Xi], 
                                  SequenceForm[ 
                                    StyleForm[ z, ShowContents -> False]], 
                                  SequenceForm[ z]],
                                Editable->False],
                              "TraditionalForm"],
                            "TraditionalForm"], ")"}], "2"],
                      DisplayForm],
                    "TraditionalForm"]}], ")"}]}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Let's see if the x-component of the angular  momentum is conserved.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetAttributes[m, Constant];\)\), "\[IndentingNewLine]", 
    \(PoissonB[Lu[x], Tensor[Hc]]\), "\[IndentingNewLine]", 
    \(% // ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{"{", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["L", 
                      InterpretationBox[
                        TagBox[
                          StyleBox["x",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ x, ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox["x",
                        SequenceForm[ x],
                        Editable->False]],
                    Subsuperscript[ L, 
                      SequenceForm[ 
                        StyleForm[ x, ShowContents -> False]], 
                      SequenceForm[ x]],
                    Editable->False],
                  "TraditionalForm"], ",", 
                FormBox["Hc",
                  "TraditionalForm"]}], "}"}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["J", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\[Mu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["\[Nu]",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                    SequenceForm[ \[Mu], \[Nu]],
                    Editable->False]],
                Subsuperscript[ J, 
                  SequenceForm[ 
                    StyleForm[ \[Mu], ShowContents -> False], 
                    StyleForm[ \[Nu], ShowContents -> False]], 
                  SequenceForm[ \[Mu], \[Nu]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              TagBox[
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    FormBox["Hc",
                      "TraditionalForm"]}], 
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["\[Nu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ \[Nu], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["\[Nu]",
                            SequenceForm[ \[Nu]],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ \[Nu], ShowContents -> False]], 
                          SequenceForm[ \[Nu]]],
                        Editable->False],
                      "TraditionalForm"]}],
                  MultilineFunction->None],
                HoldForm],
              "TraditionalForm"], " ", 
            FormBox[
              TagBox[
                FractionBox[
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["L", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["x",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ x, ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["x",
                            SequenceForm[ x],
                            Editable->False]],
                        Subsuperscript[ L, 
                          SequenceForm[ 
                            StyleForm[ x, ShowContents -> False]], 
                          SequenceForm[ x]],
                        Editable->False],
                      "TraditionalForm"]}], 
                  RowBox[{"\[PartialD]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[Xi]", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["\[Mu]",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ \[Mu], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["\[Mu]",
                            SequenceForm[ \[Mu]],
                            Editable->False]],
                        Subsuperscript[ \[Xi], 
                          SequenceForm[ 
                            StyleForm[ \[Mu], ShowContents -> False]], 
                          SequenceForm[ \[Mu]]],
                        Editable->False],
                      "TraditionalForm"]}],
                  MultilineFunction->None],
                HoldForm],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox["0",
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["Homework: Prove that for the other components  too.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(homework[PoissonB[Lu[y], Tensor[Hc]], 
      PoissonB[Lu[z], Tensor[Hc]]]\), "\[IndentingNewLine]", 
    \(ExpandPoissonB[{\[Xi], \[Delta], g, \[CapitalGamma]}, 
        J, {\[Mu], \[Nu]}] /@ %\), "\[IndentingNewLine]", 
    \(ToArrayValues /@ %\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"homework", "(", 
            RowBox[{
              FormBox[
                RowBox[{"{", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["L", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["y",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ y, ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["y",
                            SequenceForm[ y],
                            Editable->False]],
                        Subsuperscript[ L, 
                          SequenceForm[ 
                            StyleForm[ y, ShowContents -> False]], 
                          SequenceForm[ y]],
                        Editable->False],
                      "TraditionalForm"], ",", 
                    FormBox["Hc",
                      "TraditionalForm"]}], "}"}],
                "TraditionalForm"], ",", 
              FormBox[
                RowBox[{"{", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["L", 
                          InterpretationBox[
                            TagBox[
                              StyleBox["z",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ z, ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox["z",
                            SequenceForm[ z],
                            Editable->False]],
                        Subsuperscript[ L, 
                          SequenceForm[ 
                            StyleForm[ z, ShowContents -> False]], 
                          SequenceForm[ z]],
                        Editable->False],
                      "TraditionalForm"], ",", 
                    FormBox["Hc",
                      "TraditionalForm"]}], "}"}],
                "TraditionalForm"]}], ")"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{"homework", "(", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["J", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["\[Mu]",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["\[Nu]",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ \[Mu], ShowContents -> False], 
                          StyleForm[ \[Nu], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                        SequenceForm[ \[Mu], \[Nu]],
                        Editable->False]],
                    Subsuperscript[ J, 
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]], 
                      SequenceForm[ \[Mu], \[Nu]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  TagBox[
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        FormBox["Hc",
                          "TraditionalForm"]}], 
                      RowBox[{"\[PartialD]", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Xi]", 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["\[Nu]",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ \[Nu], ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox["\[Nu]",
                                SequenceForm[ \[Nu]],
                                Editable->False]],
                            Subsuperscript[ \[Xi], 
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]], 
                              SequenceForm[ \[Nu]]],
                            Editable->False],
                          "TraditionalForm"]}],
                      MultilineFunction->None],
                    HoldForm],
                  "TraditionalForm"], " ", 
                FormBox[
                  TagBox[
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["L", 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["y",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ y, ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox["y",
                                SequenceForm[ y],
                                Editable->False]],
                            Subsuperscript[ L, 
                              SequenceForm[ 
                                StyleForm[ y, ShowContents -> False]], 
                              SequenceForm[ y]],
                            Editable->False],
                          "TraditionalForm"]}], 
                      RowBox[{"\[PartialD]", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Xi]", 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["\[Mu]",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ \[Mu], ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox["\[Mu]",
                                SequenceForm[ \[Mu]],
                                Editable->False]],
                            Subsuperscript[ \[Xi], 
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]], 
                              SequenceForm[ \[Mu]]],
                            Editable->False],
                          "TraditionalForm"]}],
                      MultilineFunction->None],
                    HoldForm],
                  "TraditionalForm"]}], ",", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["J", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["\[Mu]",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["\[Nu]",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ \[Mu], ShowContents -> False], 
                          StyleForm[ \[Nu], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                        SequenceForm[ \[Mu], \[Nu]],
                        Editable->False]],
                    Subsuperscript[ J, 
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]], 
                      SequenceForm[ \[Mu], \[Nu]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  TagBox[
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        FormBox["Hc",
                          "TraditionalForm"]}], 
                      RowBox[{"\[PartialD]", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Xi]", 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["\[Nu]",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ \[Nu], ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox["\[Nu]",
                                SequenceForm[ \[Nu]],
                                Editable->False]],
                            Subsuperscript[ \[Xi], 
                              SequenceForm[ 
                                StyleForm[ \[Nu], ShowContents -> False]], 
                              SequenceForm[ \[Nu]]],
                            Editable->False],
                          "TraditionalForm"]}],
                      MultilineFunction->None],
                    HoldForm],
                  "TraditionalForm"], " ", 
                FormBox[
                  TagBox[
                    FractionBox[
                      RowBox[{"\[PartialD]", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["L", 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["z",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ z, ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox["z",
                                SequenceForm[ z],
                                Editable->False]],
                            Subsuperscript[ L, 
                              SequenceForm[ 
                                StyleForm[ z, ShowContents -> False]], 
                              SequenceForm[ z]],
                            Editable->False],
                          "TraditionalForm"]}], 
                      RowBox[{"\[PartialD]", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[Xi]", 
                              InterpretationBox[
                                TagBox[
                                  StyleBox["\[Mu]",
                                    ShowContents->False],
                                  (StyleForm[ #, ShowContents -> False]&)],
                                SequenceForm[ 
                                  StyleForm[ \[Mu], ShowContents -> False]],
                                Editable->False], 
                              InterpretationBox["\[Mu]",
                                SequenceForm[ \[Mu]],
                                Editable->False]],
                            Subsuperscript[ \[Xi], 
                              SequenceForm[ 
                                StyleForm[ \[Mu], ShowContents -> False]], 
                              SequenceForm[ \[Mu]]],
                            Editable->False],
                          "TraditionalForm"]}],
                      MultilineFunction->None],
                    HoldForm],
                  "TraditionalForm"]}]}], ")"}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\(homework(0, 0)\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
This means that we have three independent integrals of motion: the \
Hamiltonian, the square angular momentum and one of the component.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 27, 0, 76, "Title"],
Cell[1757, 54, 76, 4, 79, "Subsubtitle"],
Cell[1836, 60, 142, 2, 66, "Input"],

Cell[CellGroupData[{
Cell[2003, 66, 64, 0, 49, "Subsection"],
Cell[2070, 68, 208, 5, 54, "Text"],
Cell[2281, 75, 522, 25, 55, "Text"],
Cell[2806, 102, 140, 2, 66, "Input"],
Cell[2949, 106, 346, 6, 86, "Input"],

Cell[CellGroupData[{
Cell[3320, 116, 200, 3, 86, "Input"],
Cell[3523, 121, 647, 16, 127, "Output"]
}, Open  ]],
Cell[4185, 140, 65, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[4275, 144, 273, 5, 86, "Input"],
Cell[4551, 151, 3677, 90, 35, "Output"],
Cell[8231, 243, 3677, 90, 35, "Output"],
Cell[11911, 335, 3677, 90, 32, "Output"]
}, Open  ]],
Cell[15603, 428, 178, 5, 35, "Text"],
Cell[15784, 435, 82, 1, 46, "Input"],
Cell[15869, 438, 345, 12, 54, "Text"],

Cell[CellGroupData[{
Cell[16239, 454, 250, 4, 86, "Input"],
Cell[16492, 460, 2221, 52, 32, "Output"],
Cell[18716, 514, 5011, 113, 51, "Output"],
Cell[23730, 629, 4050, 93, 35, "Output"]
}, Open  ]],
Cell[27795, 725, 571, 21, 74, "Text"],
Cell[28369, 748, 93, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[28487, 754, 335, 6, 86, "Input"],
Cell[28825, 762, 4388, 94, 32, "Output"],
Cell[33216, 858, 18019, 374, 77, "Output"],
Cell[51238, 1234, 8013, 182, 34, "Output"]
}, Open  ]],
Cell[59266, 1419, 206, 6, 54, "Text"],

Cell[CellGroupData[{
Cell[59497, 1429, 259, 5, 86, "Input"],
Cell[59759, 1436, 2987, 72, 32, "Output"],
Cell[62749, 1510, 6979, 153, 54, "Output"],
Cell[69731, 1665, 227, 7, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69995, 1677, 259, 5, 86, "Input"],
Cell[70257, 1684, 2987, 72, 32, "Output"],
Cell[73247, 1758, 6979, 153, 54, "Output"],
Cell[80229, 1913, 227, 7, 29, "Output"]
}, Open  ]],
Cell[80471, 1923, 107, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[80603, 1932, 70, 1, 46, "Input"],
Cell[80676, 1935, 3994, 92, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84707, 2032, 304, 5, 106, "Input"],
Cell[85014, 2039, 6107, 127, 34, "Output"],
Cell[91124, 2168, 7831, 170, 34, "Output"],
Cell[98958, 2340, 20614, 443, 54, "Output"],
Cell[119575, 2785, 224, 7, 29, "Output"]
}, Open  ]],
Cell[119814, 2795, 187, 4, 74, "Text"],
Cell[120004, 2801, 431, 7, 108, "EmphasisText"],
Cell[120438, 2810, 203, 4, 54, "Text"],
Cell[120644, 2816, 252, 4, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120933, 2825, 66, 0, 49, "Subsection"],
Cell[121002, 2827, 660, 18, 54, "Text"],

Cell[CellGroupData[{
Cell[121687, 2849, 243, 4, 86, "Input"],
Cell[121933, 2855, 2221, 52, 32, "Output"],
Cell[124157, 2909, 4080, 94, 35, "Output"],
Cell[128240, 3005, 244, 7, 29, "Output"]
}, Open  ]],
Cell[128499, 3015, 112, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[128636, 3022, 245, 4, 86, "Input"],
Cell[128884, 3028, 1372, 34, 32, "Output"],
Cell[130259, 3064, 4126, 95, 51, "Output"],
Cell[134388, 3161, 1553, 38, 50, "Output"]
}, Open  ]],
Cell[135956, 3202, 108, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[136089, 3209, 252, 4, 86, "Input"],
Cell[136344, 3215, 2101, 51, 32, "Output"],
Cell[138448, 3268, 4069, 94, 34, "Output"],
Cell[142520, 3364, 224, 7, 29, "Output"]
}, Open  ]],
Cell[142759, 3374, 206, 4, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143002, 3383, 54, 0, 49, "Subsection"],
Cell[143059, 3385, 144, 3, 34, "Text"],
Cell[143206, 3390, 206, 4, 66, "Input"],

Cell[CellGroupData[{
Cell[143437, 3398, 73, 1, 46, "Input"],
Cell[143513, 3401, 9450, 193, 56, "Output"]
}, Open  ]],
Cell[152978, 3597, 91, 2, 34, "Text"],

Cell[CellGroupData[{
Cell[153094, 3603, 299, 5, 106, "Input"],
Cell[153396, 3610, 1275, 33, 30, "Output"],
Cell[154674, 3645, 5033, 114, 52, "Output"],
Cell[159710, 3761, 224, 7, 29, "Output"]
}, Open  ]],
Cell[159949, 3771, 67, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[160041, 3775, 280, 5, 86, "Input"],
Cell[160324, 3782, 2610, 61, 32, "Output"],
Cell[162937, 3845, 10774, 223, 54, "Output"],
Cell[173714, 4070, 239, 7, 29, "Output"]
}, Open  ]],
Cell[173968, 4080, 159, 3, 54, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

