(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10071,        369]*)
(*NotebookOutlinePosition[     10754,        392]*)
(*  CellTagsIndexPosition[     10710,        388]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Lie Perturbation Technique", "Title"],

Cell["\<\
Renan Cabrera
rencabla@ceibo.entelnet.bo
2003\
\>", "Subsubtitle"],

Cell["\<\
When we used a canonical transformation to simplify the Hamiltonian of the \
harmonic oscillator (see example of generators), the big question was: how \
did we get that transformation? One possibility is to solve the  \
Hamilton-Jacobi equation of the harmonic oscillator, which is a nonlinear \
partial differential equation of first order and very difficult to solve. \
Fortunately that equation is solvable for the harmonic oscillator but that is \
the exception to the rule and we must do something else to solve more general \
problems. \
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
A perturbation theory in general is a technique that assumes that the problem \
can be decomposed into two parts; one part with the solution perfectly known \
and a second part which is small and known as a perturbation. The final \
solution is found in terms of the known solutions. In our case we just need \
to be sure that the zero order term of the original Hamiltonian is completely \
integrable.\
\>", "Text"],

Cell["Lets start with the following canonical transformation:", "Text"],

Cell[TextData[{
  "\[Eta] = ",
  StyleBox["T",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " \[Xi]"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "where ",
  StyleBox["T",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " generates a canonical transformation parametrized by \[Epsilon] (not the \
time), which is small."
}], "Text"],

Cell["\<\
Again, if  K(\[Eta]) and H(\[Xi]) are the new and old representations of the \
Hamiltonian then we have,\
\>", "Text"],

Cell[TextData[{
  "K(\[Eta]) = ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          StyleBox["T",
            FontSize->16,
            FontSlant->"Italic"], \(\(\ \)\(-1\)\)],
        FontSize->16]]],
  "H(",
  StyleBox["T",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\[Xi] )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
where we used the identity obeyed by the invariance of a scalar tensor and \
the action of an operator in a function.\
\>", "Text"],

Cell["And finally we get the MASTER equation:", "Text"],

Cell[TextData[{
  "K(\[Eta]) = ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          StyleBox["T",
            FontSize->16,
            FontSlant->"Italic"], \(\(\ \)\(-1\)\)],
        FontSize->16]]],
  "H(",
  "\[Eta]",
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "This means that if we want to get the new representation of the \
Hamiltonian, we just have to apply the inverse transformation operator ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          StyleBox["T",
            FontSize->16,
            FontSlant->"Italic"], \(\(\ \)\(-1\)\)],
        FontSize->16]]],
  " over the old Hamiltonian in the new coordinates!"
}], "Text"],

Cell["\<\
Lie Perturbation Technique 
\[FilledSmallSquare] Make a series expansion of the inverse  transformation \
operator using as a generator a series of unknown generators.
\[FilledSmallSquare] Apply the inverse transformation operator to the old \
hamiltonian on the new coordinates.
\[FilledSmallSquare] Apply conditions to each order of the expansion to \
constrain the unknown generators from the transformation operator so that the \
new Hamiltonian will be a function of only the momenta.\
\>", "EmphasisText"],

Cell[CellGroupData[{

Cell["\<\
Series expansion of the transformation operator and calculation of its \
inverse\
\>", "Section"],

Cell["The staring point is:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["T",
        FontSize->16,
        FontWeight->"Bold",
        FontSlant->"Italic"], 
      "=", \(\[ExponentialE]\^\(-\(\[Integral]{\(G\)\(,\)\ \ \ \ } \
\[DifferentialD]\[Epsilon]\)\)\)}]], "Text",
  TextAlignment->Center,
  TextJustification->0,
  FontSize->18],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\[IndentingNewLine]", 
    \(Needs["\<TMecanica1`TMecanica`\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell["Series Expansion", "Subsection"],

Cell["\<\
Let's first expand the generator G using the GeneratorPerturbationExpansion \
function.\
\>", "Text"],

Cell["Two terms are enough to find a second order transformation.", "Text"],

Cell[BoxData[
    \(\(?GeneratorPerturbationExpansion\)\)], "Input"],

Cell[BoxData[
    \(GeneratorPerturbationExpansion[G, \[Epsilon], 2]\)], "Input"],

Cell["\<\
where we chose this truncation to have a final precision of second order in \
\[Epsilon]. All the other higher orders are going to be out of interest now \
but they are going to appear eventually.\
\>", "Text"],

Cell["\<\
The expansion of the transformation operator is carried out by the following \
function:\
\>", "Text"],

Cell[BoxData[
    \(\(?TOperatorPerturbationExpansion\)\)], "Input"],

Cell["Let's start with a series expansion of 2 initial terms.", "Text"],

Cell[BoxData[
    \(TOperatorPerturbationExpansion[G, Tensor[W], \[Epsilon], 2]\)], "Input"],

Cell["\<\
We are interested up to the second order. In order to be sure we expand with \
one additional order.\
\>", "Text"],

Cell[BoxData[
    \(TOperatorPerturbationExpansion[G, Tensor[W], \[Epsilon], 3]\)], "Input"],

Cell["\<\
The answer is the same up to the second order, so now we are sure of them.\
\>", "Text"],

Cell["\<\
We are really interested in the inverse transformation operator, which can be \
calculated by the following function:\
\>", "Text"],

Cell[BoxData[
    \(\(?InverseTOperatorPerturbationExpansion\)\)], "Input"],

Cell["\<\
The calculation of the expansion of the inverse operator starting from a \
generator  expanded with two therms. \
\>", "Text"],

Cell[BoxData[
    \(InverseTOperatorPerturbationExpansion[G, Tensor[W], \[Epsilon], 
      2]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Identification of the Series Expansion", "Section"],

Cell["Now is time to use the MASTER equation:", "Text"],

Cell[TextData[{
  "K(\[Eta]) = ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          StyleBox["T",
            FontSize->16,
            FontSlant->"Italic"], \(\(\ \)\(-1\)\)],
        FontSize->16]]],
  "H(",
  "\[Eta]",
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The expansion of the new Hamiltonian K is carried out by the following \
function:\
\>", "Text"],

Cell[BoxData[
    \(\(?HamiltonianPerturbationExpansion\)\)], "Input"],

Cell[BoxData[
    \(HamiltonianPerturbationExpansion[K, \[Epsilon], 2]\)], "Input"],

Cell["Similarly the old Hamiltonian expanded:", "Text"],

Cell[BoxData[
    \(HamiltonianPerturbationExpansion[H, \[Epsilon], 2]\)], "Input"],

Cell["Finally the MASTER equation is:", "Text"],

Cell[TextData[{
  "K(\[Eta]) = ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          StyleBox["T",
            FontSize->16,
            FontSlant->"Italic"], \(\(\ \)\(-1\)\)],
        FontSize->16]]],
  "H(",
  "\[Eta]",
  " )"
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The right part becomes the following expression up to second order.\
\>", "Text"],

Cell[BoxData[
    \(MASTERright\  = \ 
      Collect[Expand[
          InverseTOperatorPerturbationExpansion[G, Tensor[W], \[Epsilon], 2] /. 
            Tensor[W] \[Rule] 
              HamiltonianPerturbationExpansion[H, \[Epsilon], 
                2]]\[IndentingNewLine], \[Epsilon]]\)], "Input"],

Cell[BoxData[
    \(MASTERleft\  = \ 
      HamiltonianPerturbationExpansion[K, \[Epsilon], 2]\)], "Input"],

Cell[BoxData[
    \(\(MASTER = \((MASTERleft == MASTERright)\);\)\)], "Input"],

Cell[CellGroupData[{

Cell["Zero order:", "Subsubsection"],

Cell[BoxData[
    \(\(?ExtractSeriesTerm\)\)], "Input"],

Cell[BoxData[
    \(MASTER // ExtractSeriesTerm[\[Epsilon], 0]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["First order", "Subsubsection"],

Cell[BoxData[
    \(MASTER // ExtractSeriesTerm[\[Epsilon], 1]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second order", "Subsubsection"],

Cell[BoxData[
    \(MASTER // ExtractSeriesTerm[\[Epsilon], 2]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 43, 0, 76, "Title"],
Cell[1773, 54, 76, 4, 79, "Subsubtitle"],
Cell[1852, 60, 614, 11, 114, "Text"],
Cell[2469, 73, 426, 7, 94, "Text"],
Cell[2898, 82, 71, 0, 34, "Text"],
Cell[2972, 84, 168, 8, 35, "Text"],
Cell[3143, 94, 208, 7, 35, "Text"],
Cell[3354, 103, 128, 3, 34, "Text"],
Cell[3485, 108, 364, 16, 35, "Text"],
Cell[3852, 126, 141, 3, 34, "Text"],
Cell[3996, 131, 55, 0, 34, "Text"],
Cell[4054, 133, 305, 14, 34, "Text"],
Cell[4362, 149, 408, 11, 54, "Text"],
Cell[4773, 162, 521, 9, 148, "EmphasisText"],

Cell[CellGroupData[{
Cell[5319, 175, 107, 3, 61, "Section"],
Cell[5429, 180, 37, 0, 34, "Text"],
Cell[5469, 182, 306, 10, 39, "Text"],
Cell[5778, 194, 142, 2, 66, "Input"],

Cell[CellGroupData[{
Cell[5945, 200, 38, 0, 49, "Subsection"],
Cell[5986, 202, 111, 3, 34, "Text"],
Cell[6100, 207, 75, 0, 34, "Text"],
Cell[6178, 209, 68, 1, 46, "Input"],
Cell[6249, 212, 81, 1, 46, "Input"],
Cell[6333, 215, 220, 4, 54, "Text"],
Cell[6556, 221, 112, 3, 34, "Text"],
Cell[6671, 226, 68, 1, 46, "Input"],
Cell[6742, 229, 71, 0, 34, "Text"],
Cell[6816, 231, 92, 1, 46, "Input"],
Cell[6911, 234, 124, 3, 34, "Text"],
Cell[7038, 239, 92, 1, 46, "Input"],
Cell[7133, 242, 98, 2, 34, "Text"],
Cell[7234, 246, 141, 3, 34, "Text"],
Cell[7378, 251, 75, 1, 46, "Input"],
Cell[7456, 254, 136, 3, 34, "Text"],
Cell[7595, 259, 106, 2, 46, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7750, 267, 57, 0, 61, "Section"],
Cell[7810, 269, 55, 0, 34, "Text"],
Cell[7868, 271, 305, 14, 34, "Text"],
Cell[8176, 287, 106, 3, 34, "Text"],
Cell[8285, 292, 70, 1, 46, "Input"],
Cell[8358, 295, 83, 1, 46, "Input"],
Cell[8444, 298, 55, 0, 34, "Text"],
Cell[8502, 300, 83, 1, 46, "Input"],
Cell[8588, 303, 47, 0, 34, "Text"],
Cell[8638, 305, 305, 14, 34, "Text"],
Cell[8946, 321, 91, 2, 34, "Text"],
Cell[9040, 325, 300, 6, 106, "Input"],
Cell[9343, 333, 107, 2, 46, "Input"],
Cell[9453, 337, 78, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[9556, 342, 36, 0, 43, "Subsubsection"],
Cell[9595, 344, 55, 1, 46, "Input"],
Cell[9653, 347, 75, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9765, 353, 36, 0, 43, "Subsubsection"],
Cell[9804, 355, 75, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9916, 361, 37, 0, 43, "Subsubsection"],
Cell[9956, 363, 75, 1, 46, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

