(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4176,        140]*)
(*NotebookOutlinePosition[      5183,        175]*)
(*  CellTagsIndexPosition[      5109,        169]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ExpandedTOperator", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"ExpandedTOperator", 
          StyleBox["[",
            "MR"], 
          
          StyleBox[\({x, \[Delta], g, \[CapitalGamma], J}, G, \[Epsilon], 
            n, \ flavor\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["W",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " gives the nth order expansion of the operator T of the accumulative \
effect of infinitesimal canonical transformations generated by G  in the \
parameter \[Epsilon]. "
}], "Usage",
  CellTags->"Function?"],

Cell[" G and W must be tensor objects.", "MathCaption"],

Cell[TextData[{
  "   The difference with TOperator is that here the expansion is fully \
evaluated and we assume that G",
  StyleBox[" does not depend ",
    FontSlant->"Italic"],
  "on the expansion parameter  \[Epsilon], which is useful for most of the \
intersting cases."
}], "MathCaption"],

Cell["\<\
  Be careful not to apply this expansion to generators expanded in a \
perturbative series because in this case the perturbation parameter appears \
explicitly in the whole generator.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["TOperator",
    ButtonData:>{"TOperator"},
    ButtonStyle->"AddOnsLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(Needs["\<TMecanica1`TMecanica`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[{1, 2}]\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Let's use \[Xi] as the label of the coordinates to avoid confusion.\
\>", "Text"],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{\[Xi]}, 1}, {{\[Delta], W, J}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {\[Xi], \[Delta], g, \[CapitalGamma]};\)\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(SetSymplecticJValues[J, NDim, red]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(\(ExpandedTOperator[{x, \[Delta], g, \[CapitalGamma]}, J, Tensor[G], t, 
        2, red]\)[Tensor[W]]\)], "Input",
  CellLabel->"In[8]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{719, 487},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 668, 23, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 4938, 160}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 668, 23, 49, "Usage",
  CellTags->"Function?"],
Cell[2514, 81, 55, 0, 31, "MathCaption"],
Cell[2572, 83, 295, 7, 48, "MathCaption"],
Cell[2870, 92, 214, 4, 48, "MathCaption"],
Cell[3087, 98, 137, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3249, 107, 34, 0, 40, "ExampleSection"],
Cell[3286, 109, 149, 3, 49, "Input"],
Cell[3438, 114, 149, 3, 49, "Input"],
Cell[3590, 119, 91, 2, 25, "Text"],
Cell[3684, 123, 209, 4, 49, "Input"],
Cell[3896, 129, 91, 2, 29, "Input"],
Cell[3990, 133, 158, 3, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

