(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18101,        413]*)
(*NotebookOutlinePosition[     19109,        448]*)
(*  CellTagsIndexPosition[     19034,        442]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["InverseTOperatorPerturbationExpansion", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"InverseTOperatorPerturbationExpansion", 
        StyleBox["[",
          "MR"], 
        StyleBox[\(G, W, \[Epsilon], n\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " ",
  "will create a perturbative series expansion of the inverse transformation \
operator with generator G expanded into a perturbative series, applied to a \
tensor W in terms of the parameter \[Epsilon]. The original series expansion \
of  the Generator is of nth order."
}], "Usage",
  CellTags->"Function?"],

Cell[" G is a Symbol and W must be a tensor object.", "MathCaption"],

Cell["\<\
 The generator G can depend on the perturbation parametr \[Epsilon].\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["GeneratorPerturbationExpansion",
    ButtonData:>{"GeneratorPerturbationExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TOperatorPerturbationExpansion",
    ButtonData:>{"TOperatorPerturbationExpansion"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(Needs["\<TMecanica1`TMecanica`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[{x, p}]\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{{\[Xi], x}, 1}, {{\[Delta], J}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {\[Xi], \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(\(SetTensorValues[\[Delta]ud[i, j], 
        IdentityMatrix[NDim]];\)\), "\[IndentingNewLine]", 
    \(SetSymplecticJValues[J, NDim]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseTOperatorPerturbationExpansion[G, Tensor[W], \[Epsilon], 
      2]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{\(1\/8\), " ", 
              FormBox[
                RowBox[{"{", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["G", 
                          InterpretationBox["2",
                            SequenceForm[ 2],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox["2",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 2, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ G, 
                          SequenceForm[ 2], 
                          SequenceForm[ 
                            StyleForm[ 2, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], ",", 
                    FormBox[
                      RowBox[{"{", 
                        RowBox[{
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["G", 
                                InterpretationBox["2",
                                  SequenceForm[ 2],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["2",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ 2, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ G, 
                                SequenceForm[ 2], 
                                SequenceForm[ 
                                  StyleForm[ 2, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], ",", 
                          FormBox["W",
                            "TraditionalForm"]}], "}"}],
                      "TraditionalForm"]}], "}"}],
                "TraditionalForm"], " ", \(\[Epsilon]\^4\)}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/6\), " ", 
                    FormBox[
                      RowBox[{"{", 
                        RowBox[{
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["G", 
                                InterpretationBox["1",
                                  SequenceForm[ 1],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["1",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ 1, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ G, 
                                SequenceForm[ 1], 
                                SequenceForm[ 
                                  StyleForm[ 1, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], ",", 
                          FormBox[
                            RowBox[{"{", 
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["G", 
                                      InterpretationBox["2",
                                        SequenceForm[ 2],
                                        Editable->False], 
                                      InterpretationBox[
                                        TagBox[
                                        StyleBox["2",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)],
                                        SequenceForm[ 
                                        StyleForm[ 2, ShowContents -> False]],
                                        
                                        Editable->False]],
                                    Subsuperscript[ G, 
                                      SequenceForm[ 2], 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        2, ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"], ",", 
                                FormBox["W",
                                  "TraditionalForm"]}], "}"}],
                            "TraditionalForm"]}], "}"}],
                      "TraditionalForm"]}], "+", 
                  RowBox[{\(1\/3\), " ", 
                    FormBox[
                      RowBox[{"{", 
                        RowBox[{
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["G", 
                                InterpretationBox["2",
                                  SequenceForm[ 2],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["2",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ 2, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ G, 
                                SequenceForm[ 2], 
                                SequenceForm[ 
                                  StyleForm[ 2, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], ",", 
                          FormBox[
                            RowBox[{"{", 
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["G", 
                                      InterpretationBox["1",
                                        SequenceForm[ 1],
                                        Editable->False], 
                                      InterpretationBox[
                                        TagBox[
                                        StyleBox["1",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)],
                                        SequenceForm[ 
                                        StyleForm[ 1, ShowContents -> False]],
                                        
                                        Editable->False]],
                                    Subsuperscript[ G, 
                                      SequenceForm[ 1], 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        1, ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"], ",", 
                                FormBox["W",
                                  "TraditionalForm"]}], "}"}],
                            "TraditionalForm"]}], "}"}],
                      "TraditionalForm"]}]}], ")"}], " ", \(\[Epsilon]\^3\)}],
             "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(1\/2\), " ", 
                    FormBox[
                      RowBox[{"{", 
                        RowBox[{
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["G", 
                                InterpretationBox["1",
                                  SequenceForm[ 1],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["1",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ 1, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ G, 
                                SequenceForm[ 1], 
                                SequenceForm[ 
                                  StyleForm[ 1, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], ",", 
                          FormBox[
                            RowBox[{"{", 
                              RowBox[{
                                FormBox[
                                  InterpretationBox[
                                    SubsuperscriptBox["G", 
                                      InterpretationBox["1",
                                        SequenceForm[ 1],
                                        Editable->False], 
                                      InterpretationBox[
                                        TagBox[
                                        StyleBox["1",
                                        ShowContents->False],
                                        (
                                        StyleForm[ #, ShowContents -> 
                                        False]&)],
                                        SequenceForm[ 
                                        StyleForm[ 1, ShowContents -> False]],
                                        
                                        Editable->False]],
                                    Subsuperscript[ G, 
                                      SequenceForm[ 1], 
                                      SequenceForm[ 
                                        StyleForm[ 
                                        1, ShowContents -> False]]],
                                    Editable->False],
                                  "TraditionalForm"], ",", 
                                FormBox["W",
                                  "TraditionalForm"]}], "}"}],
                            "TraditionalForm"]}], "}"}],
                      "TraditionalForm"]}], "+", 
                  RowBox[{\(1\/2\), " ", 
                    FormBox[
                      RowBox[{"{", 
                        RowBox[{
                          FormBox[
                            InterpretationBox[
                              SubsuperscriptBox["G", 
                                InterpretationBox["2",
                                  SequenceForm[ 2],
                                  Editable->False], 
                                InterpretationBox[
                                  TagBox[
                                    StyleBox["2",
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)],
                                  SequenceForm[ 
                                    StyleForm[ 2, ShowContents -> False]],
                                  Editable->False]],
                              Subsuperscript[ G, 
                                SequenceForm[ 2], 
                                SequenceForm[ 
                                  StyleForm[ 2, ShowContents -> False]]],
                              Editable->False],
                            "TraditionalForm"], ",", 
                          FormBox["W",
                            "TraditionalForm"]}], "}"}],
                      "TraditionalForm"]}]}], ")"}], " ", \(\[Epsilon]\^2\)}],
             "+", 
            RowBox[{
              FormBox[
                RowBox[{"{", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["G", 
                          InterpretationBox["1",
                            SequenceForm[ 1],
                            Editable->False], 
                          InterpretationBox[
                            TagBox[
                              StyleBox["1",
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 1, ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ G, 
                          SequenceForm[ 1], 
                          SequenceForm[ 
                            StyleForm[ 1, ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], ",", 
                    FormBox["W",
                      "TraditionalForm"]}], "}"}],
                "TraditionalForm"], " ", "\[Epsilon]"}], "+", 
            FormBox["W",
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output",
  CellLabel->"Out[8]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 84, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1863, 56, 574, 16, 66, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 18863, 433}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 84, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1863, 56, 574, 16, 66, "Usage",
  CellTags->"Function?"],
Cell[2440, 74, 68, 0, 31, "MathCaption"],
Cell[2511, 76, 99, 2, 31, "MathCaption"],
Cell[2613, 80, 324, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2962, 94, 34, 0, 40, "ExampleSection"],
Cell[2999, 96, 149, 3, 49, "Input"],
Cell[3151, 101, 446, 9, 109, "Input"],

Cell[CellGroupData[{
Cell[3622, 114, 130, 3, 29, "Input"],
Cell[3755, 119, 14306, 289, 80, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

